# Comparison of single-paternity and multiple-paternity nests
# Three fitness measures - fertility, hatching, and emergence
# Emergence is the one used in the paper
# No HFCs are present in this script
# May want to do two versions of MP v SP nests - with and without 'failed' nests (Incub = NA)
# Consider controlling for lay date and incubation

# Revised 2017-08-01 for Dryad
#  - tidied, streamlined, and better annotated

#--------------------------------------------------------------------------------------------
# Clear R
rm(list = ls())

# Load necessary packages
library(MASS)
library(lme4)
library(lmerTest)
library(moments)
library(MuMIn)
#--------------------------------------------------------------------------------------------


#--------------------------------------------------------------------------------------------
####  BRING IN DATA  ########

# Set WD
setwd("FILEPATH")

# Read datafile
data.FULL <- read.csv("00_HFC_extendedData.csv")
#--------------------------------------------------------------------------------------------


#--------------------------------------------------------------------------------------------
## Code for Nakagawa Rsq for LMM
## http://jslefche.wordpress.com/2013/03/13/r2-for-linear-mixed-effects-models/
## Updated by us, as original was written for lme4 in R v2

rsquared.lme=function(modlist) {
  #Iterate over each model in the list
  do.call(rbind,lapply(modlist,function(i) {
    #For models fit using lm
    if(class(i)=="lm") {
      Rsquared.mat=data.frame(Class=class(i),Marginal=summary(i)$r.squared,
                              Conditional=NA,AIC=AIC(i)) } 
    #For models fit using lme4
    else if(class(i)=="mer" | class(i)=="merMod" | class(i)=="merLmerTest") {
      #Get variance of fixed effects by multiplying coefficients by design matrix
      VarF=var(as.vector(fixef(i) %*% t(i@X))) 
      #Get variance of random effects by extracting variance components
      VarRand=colSums(do.call(rbind,lapply(VarCorr(i),function(j) j[1])))
      #Get residual variance
      VarResid=attr(VarCorr(i),"sc")^2
      #Calculate marginal R-squared (fixed effects/total variance)
      Rm=VarF/(VarF+VarRand+VarResid)
      #Calculate conditional R-squared (fixed effects+random effects/total variance)
      Rc=(VarF+VarRand)/(VarF+VarRand+VarResid)
      #Bind R^2s into a matrix and return with AIC values
      Rsquared.mat=data.frame(Class=class(i),Marginal=Rm,Conditional=Rc,
                              AIC=AIC(update(i,REML=F))) } 
    #For models fit using NEWER VERSION of lme4 WITH lmerTest
    else if(class(i)=="lmerMod" | class(i)=="merModLmerTest") {
      #Get variance of fixed effects by multiplying coefficients by design matrix
      VarF=var(as.vector(fixef(i) %*% t(i@pp$X))) 
      #Get variance of random effects by extracting variance components
      VarRand=colSums(do.call(rbind,lapply(VarCorr(i),function(j) j[1])))
      #Get residual variance
      VarResid=attr(VarCorr(i),"sc")^2
      #Calculate marginal R-squared (fixed effects/total variance)
      Rm=VarF/(VarF+VarRand+VarResid)
      #Calculate conditional R-squared (fixed effects+random effects/total variance)
      Rc=(VarF+VarRand)/(VarF+VarRand+VarResid)
      #Bind R^2s into a matrix and return with AIC values
      Rsquared.mat=data.frame(Class=class(i),Marginal=Rm,Conditional=Rc,
                              AIC=AIC(update(i,REML=F))) } 
    #For model fit using nlme  
    else if(class(i)=="lme") {
      #Get design matrix of fixed effects from model
      Fmat=model.matrix(eval(i$call$fixed)[-2],i$data)
      #Get variance of fixed effects by multiplying coefficients by design matrix
      VarF=var(as.vector(fixef(i) %*% t(Fmat)))
      #Get variance of random effects by extracting variance components
      VarRand=sum(suppressWarnings(as.numeric(VarCorr(i)[rownames(VarCorr(i))!=
                                                           "Residual",1])),na.rm=T)
      #Get residual variance
      VarResid=as.numeric(VarCorr(i)[rownames(VarCorr(i))=="Residual",1])
      #Calculate marginal R-squared (fixed effects/total variance)
      Rm=VarF/(VarF+VarRand+VarResid)
      #Calculate conditional R-squared (fixed effects+random effects/total variance)
      Rc=(VarF+VarRand)/(VarF+VarRand+VarResid)
      #Bind R^2s into a matrix and return with AIC values
      Rsquared.mat=data.frame(Class=class(i),Marginal=Rm,Conditional=Rc,
                              AIC=AIC(update(i,method="ML")))
    } else { print("Function requires models of class lm, lme, mer, or merMod") 
    } } ) ) }
#  rsquared.lme(list( ENTER MODEL NAMES HERE ))
#--------------------------------------------------------------------------------------------


#--------------------------------------------------------------------------------------------
##  Collinearity diagnostics

vif.mer <- function (fit) {
  ## adapted from rms::vif
  
  v <- vcov(fit)
  nam <- names(fixef(fit))
  
  ## exclude intercepts
  ns <- sum(1 * (nam == "Intercept" | nam == "(Intercept)"))
  if (ns > 0) {
    v <- v[-(1:ns), -(1:ns), drop = FALSE]
    nam <- nam[-(1:ns)]
  }
  
  d <- diag(v)^0.5
  v <- diag(solve(v/(d %o% d)))
  names(v) <- nam
  v
}

kappa.mer <- function (fit,
                       scale = TRUE, center = FALSE,
                       add.intercept = TRUE,
                       exact = FALSE) {
  X <- fit@pp$X
  nam <- names(fixef(fit))
  
  ## exclude intercepts
  nrp <- sum(1 * (nam == "(Intercept)"))
  if (nrp > 0) {
    X <- X[, -(1:nrp), drop = FALSE]
    nam <- nam[-(1:nrp)]
  }
  
  if (add.intercept) {
    X <- cbind(rep(1), scale(X, scale = scale, center = center))
    kappa(X, exact = exact)
  } else {
    kappa(scale(X, scale = scale, center = scale), exact = exact)
  }
}
#--------------------------------------------------------------------------------------------


#--------------------------------------------------------------------------------------------
####  EXAMINE/REFINE DATA  ########
# Examine
str(data.FULL, list.len = 220)
names(data.FULL)
nrow(data.FULL)

# Columns for focal analyses
colList <- c("SP.v.MP", "paternity.type", "year", "pair.id", "female.id", "male.id",  
	"lay.date", "incub.dur.1", "eggs.laid", "CCL", "FERTILE", "HATCHED", "TO.SEA")


# Make subset for use in focal analysis
my.data <- data.FULL[data.FULL$SP.v.MP == "Y", colList]
str(my.data)
nrow(my.data)

# Redefine numerical variables that need to be factors
my.data$year <- factor(my.data$year)
my.data$pair.id <- factor(my.data$pair.id)
my.data$female.id <- factor(my.data$female.id)
my.data$male.id <- factor(my.data$male.id)
#--------------------------------------------------------------------------------------------


#--------------------------------------------------------------------------------------------
# CREATE NEW VARIABLES
#  - standardising directions of alternative H metrics
#  - mean-centering the genetic predictors
#  - make quadratic variables

# Mean-centre variables
# Date & incubation duration - though incub isn't used
my.data$lay.date.C <- scale(my.data$lay.date, center = TRUE, scale = FALSE)
my.data$incub.dur.C <- scale(my.data$incub.dur.1, center = TRUE, scale = FALSE)

# Make quadratic variables
my.data$lay.date.C.SQ <- my.data$lay.date.C^2
my.data$incub.dur.C.SQ <- my.data$incub.dur.C^2

names(my.data)
str(my.data)
#--------------------------------------------------------------------------------------------

####################################################################
####################################################################
########    ~~~~~~~~~~~~~~~~~~~~~~~    #############################
########     MAIN MODELS - SP v MP     #############################
########    ~~~~~~~~~~~~~~~~~~~~~~~    #############################
####################################################################

#--------------------------------------------------------------------------------------------
# create 'paternity.data' by removing NAs from incub.dur.C
paternity.data <- my.data[!is.na(my.data$incub.dur.C),]
nrow(paternity.data)
#--------------------------------------------------------------------------------------------


#--------------------------------------------------------------------------------------------
#%%%%%%%%%   First on 'FERTILE'   %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
#  - proportion of eggs showing development
#  - omit NAs on FERTILE

# Actual null model - no fixed terms
FERTILE.0 <- lmer(FERTILE ~ 1 + (1|female.id), 
	REML = FALSE, data = paternity.data, na.action = na.omit)

# Functional null - quadratic date and linear incubation 
FERTILE.null <- lmer(FERTILE ~ lay.date.C + lay.date.C.SQ + incub.dur.C 
	+ (1|female.id), REML = FALSE, data = paternity.data, na.action = na.omit)

# Compare models
anova(FERTILE.0, FERTILE.null)
AICc(FERTILE.0, FERTILE.null)
summary(FERTILE.null)

# Test paternity type
FERTILE.test <- lmer(FERTILE ~ lay.date.C + lay.date.C.SQ + incub.dur.C + paternity.type 
	+ (1|female.id), REML = FALSE, data = paternity.data, na.action = na.omit)

anova(FERTILE.null, FERTILE.test)		# P = 0.263
AICc(FERTILE.null, FERTILE.test)
summary(FERTILE.test)				# MP = SP + 0.275 (SE = 0.241)


# quality control

## collinearity diagnostics
vif.mer(FERTILE.null)		# all between 1.01 & 1.10
kappa.mer(FERTILE.null)		# 2.11

## Nakagawa R2
rsquared.lme(list(FERTILE.0, FERTILE.null, FERTILE.test))

## normality of residuals
shapiro.test(residuals(FERTILE.null))	# P = 0.722
skewness(residuals(FERTILE.null))		# 0.011 - fine
kurtosis(residuals(FERTILE.null))		# 2.994 - fine
hist(residuals(FERTILE.null))
#--------------------------------------------------------------------------------------------


#--------------------------------------------------------------------------------------------
#@@@@@@@@@    Next on 'HATCHED'    @@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@
#  - eggs producing hatchlings

# Actual null model - no terms
HATCHED.0 <- lmer(HATCHED ~ 1 + (1|female.id), 
	REML = FALSE, data = paternity.data, na.action = na.omit)

# Functional null - date and incubation (note: no value in incub.SQ)
HATCHED.null <- lmer(HATCHED ~ lay.date.C + lay.date.C.SQ + incub.dur.C 
	+ (1|female.id), REML = FALSE, data = paternity.data, na.action = na.omit)

# Compare models
anova(HATCHED.0, HATCHED.null)
AICc(HATCHED.0, HATCHED.null)
summary(HATCHED.null)
# Not materially different from FERTILE

# Test paternity type
HATCHED.test <- lmer(HATCHED ~ lay.date.C + lay.date.C.SQ + incub.dur.C + paternity.type 
	+ (1|female.id), REML = FALSE, data = paternity.data, na.action = na.omit)

anova(HATCHED.null, HATCHED.test)		# P = 0.190
AICc(HATCHED.null, HATCHED.test)
summary(HATCHED.test)				# MP = SP + 0.341 (SE = 0.256)


# quality control

## Collinearity diagnostics
vif.mer(HATCHED.null)		# all between 1.00 & 1.10
kappa.mer(HATCHED.null)		# 2.11

## Nakagawa R2
rsquared.lme(list(HATCHED.0, HATCHED.null, HATCHED.test))

## Normality of residuals
shapiro.test(residuals(HATCHED.null))	# P = 0.446
skewness(residuals(HATCHED.null))		# 0.071 - fine
kurtosis(residuals(HATCHED.null))		# 2.766 - fine
hist(residuals(HATCHED.null))
#--------------------------------------------------------------------------------------------


#--------------------------------------------------------------------------------------------
#@@@@@@@@@     Next on 'TO.SEA'    @@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@
#  - hatchlings that hatch and live

# remove the one nest with no offspring to sea - nest flooded on hatching, so all dead in nest
data.to.sea <- paternity.data[!is.na(paternity.data$TO.SEA),]


# Actual null model - no terms
TO.SEA.0 <- lmer(TO.SEA ~ 1 + (1|female.id), 
	REML = FALSE, data = data.to.sea, na.action = na.omit)

# Functional null - date and incubation (note: no value in incub.SQ)
TO.SEA.null <- lmer(TO.SEA ~ lay.date.C + lay.date.C.SQ + incub.dur.C 
	+ (1|female.id), REML = FALSE, data = data.to.sea, na.action = na.omit)

# Compare models
anova(TO.SEA.0, TO.SEA.null)
AICc(TO.SEA.0, TO.SEA.null)
summary(TO.SEA.null)
# Similar to FERTILE and HATCHED

# Test paternity type
TO.SEA.test <- lmer(TO.SEA ~ lay.date.C + lay.date.C.SQ + incub.dur.C + paternity.type 
	+ (1|female.id), REML = FALSE, data = data.to.sea, na.action = na.omit)

anova(TO.SEA.null, TO.SEA.test)		# P = 0.144
AICc(TO.SEA.null, TO.SEA.test)
summary(TO.SEA.test)				# MP = SP + 0.347 (SE = 0.233)


# quality control

## Collinearity diagnostics
vif.mer(TO.SEA.null)		# all between 1.00 & 1.10
kappa.mer(TO.SEA.null)		# 2.15

## Nakagawa R2
rsquared.lme(list(TO.SEA.0, TO.SEA.null, TO.SEA.test))

## Normality of residuals
shapiro.test(residuals(TO.SEA.null))	# P = 0.338
skewness(residuals(TO.SEA.null))		# -0.106 - good
kurtosis(residuals(TO.SEA.null))		# 2.580 - good
hist(residuals(TO.SEA.null))
#--------------------------------------------------------------------------------------------

