# Heterozygosity-fitness correlations against number of eggs laid by a female
# No male HFC tests are present here
# Both MLH and SLH tests are present here

# Revised 2017-08-01 for Dryad
#  - tidied, streamlined, and better annotated

#--------------------------------------------------------------------------------------------
# Clear R
rm(list = ls())

# Load necessary packages
library(MASS)
library(lme4)
library(lmerTest)
library(moments)
library(MuMIn)
#--------------------------------------------------------------------------------------------


#--------------------------------------------------------------------------------------------
####  BRING IN DATA  ########

# Set WD
setwd("FILEPATH")

# Read datafile
data.FULL <- read.csv("00_HFC_extendedData.csv")
#--------------------------------------------------------------------------------------------


#--------------------------------------------------------------------------------------------
## Code for Nakagawa Rsq for LMM
## http://jslefche.wordpress.com/2013/03/13/r2-for-linear-mixed-effects-models/
## Updated by us, as original was written for lme4 in R v2

rsquared.lme=function(modlist) {
  #Iterate over each model in the list
  do.call(rbind,lapply(modlist,function(i) {
    #For models fit using lm
    if(class(i)=="lm") {
      Rsquared.mat=data.frame(Class=class(i),Marginal=summary(i)$r.squared,
                              Conditional=NA,AIC=AIC(i)) } 
    #For models fit using lme4
    else if(class(i)=="mer" | class(i)=="merMod" | class(i)=="merLmerTest") {
      #Get variance of fixed effects by multiplying coefficients by design matrix
      VarF=var(as.vector(fixef(i) %*% t(i@X))) 
      #Get variance of random effects by extracting variance components
      VarRand=colSums(do.call(rbind,lapply(VarCorr(i),function(j) j[1])))
      #Get residual variance
      VarResid=attr(VarCorr(i),"sc")^2
      #Calculate marginal R-squared (fixed effects/total variance)
      Rm=VarF/(VarF+VarRand+VarResid)
      #Calculate conditional R-squared (fixed effects+random effects/total variance)
      Rc=(VarF+VarRand)/(VarF+VarRand+VarResid)
      #Bind R^2s into a matrix and return with AIC values
      Rsquared.mat=data.frame(Class=class(i),Marginal=Rm,Conditional=Rc,
                              AIC=AIC(update(i,REML=F))) } 
    #For models fit using NEWER VERSION of lme4 WITH lmerTest
    else if(class(i)=="lmerMod" | class(i)=="merModLmerTest") {
      #Get variance of fixed effects by multiplying coefficients by design matrix
      VarF=var(as.vector(fixef(i) %*% t(i@pp$X))) 
      #Get variance of random effects by extracting variance components
      VarRand=colSums(do.call(rbind,lapply(VarCorr(i),function(j) j[1])))
      #Get residual variance
      VarResid=attr(VarCorr(i),"sc")^2
      #Calculate marginal R-squared (fixed effects/total variance)
      Rm=VarF/(VarF+VarRand+VarResid)
      #Calculate conditional R-squared (fixed effects+random effects/total variance)
      Rc=(VarF+VarRand)/(VarF+VarRand+VarResid)
      #Bind R^2s into a matrix and return with AIC values
      Rsquared.mat=data.frame(Class=class(i),Marginal=Rm,Conditional=Rc,
                              AIC=AIC(update(i,REML=F))) } 
    #For model fit using nlme  
    else if(class(i)=="lme") {
      #Get design matrix of fixed effects from model
      Fmat=model.matrix(eval(i$call$fixed)[-2],i$data)
      #Get variance of fixed effects by multiplying coefficients by design matrix
      VarF=var(as.vector(fixef(i) %*% t(Fmat)))
      #Get variance of random effects by extracting variance components
      VarRand=sum(suppressWarnings(as.numeric(VarCorr(i)[rownames(VarCorr(i))!=
                                                           "Residual",1])),na.rm=T)
      #Get residual variance
      VarResid=as.numeric(VarCorr(i)[rownames(VarCorr(i))=="Residual",1])
      #Calculate marginal R-squared (fixed effects/total variance)
      Rm=VarF/(VarF+VarRand+VarResid)
      #Calculate conditional R-squared (fixed effects+random effects/total variance)
      Rc=(VarF+VarRand)/(VarF+VarRand+VarResid)
      #Bind R^2s into a matrix and return with AIC values
      Rsquared.mat=data.frame(Class=class(i),Marginal=Rm,Conditional=Rc,
                              AIC=AIC(update(i,method="ML")))
    } else { print("Function requires models of class lm, lme, mer, or merMod") 
    } } ) ) }
#  rsquared.lme(list( ENTER MODEL NAMES HERE ))
#--------------------------------------------------------------------------------------------


#--------------------------------------------------------------------------------------------
####  EXAMINE/REFINE DATA  ########
# Examine
str(data.FULL, list.len = 220)
names(data.FULL)
nrow(data.FULL)

# Columns for focal analyses
colList <- c("het.v.eggno", "year", "pair.id", "female.id", "male.id", "male.offspringtyped", 
	"female.H", "female.SH", "male.H", "male.SH", "female.HL", "male.HL", "female.IR", 
	"male.IR", "pair.QGt", "sim.avg", "lay.date", "incub.dur.1", "eggs.laid", "CCL", 
	"fem.loc01.S", "fem.loc02.S", "fem.loc03.S", "fem.loc04.S", "fem.loc05.S", "fem.loc06.S", 
	"fem.loc07.S", "fem.loc08.S", "fem.loc09.S", "fem.loc10.S", "fem.loc11.S", "fem.loc12.S", 
	"fem.loc13.S", "fem.loc14.S", "fem.loc15.S", "fem.loc16.S", "fem.loc17.S", "fem.loc18.S", 
	"fem.loc19.S", "fem.loc20.S", "fem.loc21.S", "fem.loc22.S", "fem.loc23.S", "fem.loc24.S", 
	"fem.loc25.S", "fem.loc26.S", "fem.loc27.S", "fem.loc28.S", "fem.loc29.S", "fem.loc30.S", 
	"fem.loc31.S", "fem.loc32.S")

# Reduce to focal rows and columns 
my.data <- data.FULL[data.FULL$het.v.eggno == "Y",colList]
nrow(my.data)

# Redefine numerical variables that need to be factors
my.data$year <- factor(my.data$year)
my.data$pair.id <- factor(my.data$pair.id)
my.data$female.id <- factor(my.data$female.id)
my.data$male.id <- factor(my.data$male.id)

# Now that multiple-paternity families have been stripped away, convert 'male.offspringtyped' to integer
my.data$male.offspringtyped <- as.integer(my.data$male.offspringtyped)
#--------------------------------------------------------------------------------------------


#--------------------------------------------------------------------------------------------
# CREATE NEW VARIABLES
#  - standardising directions of alternative H metrics
#  - mean-centering the genetic predictors
#  - make quadratic variables

# Reverse HL & IR
my.data$female.HL.rev <- 1-my.data$female.HL
my.data$male.HL.rev <- 1-my.data$male.HL
my.data$female.IR.rev <- -1*my.data$female.IR
my.data$male.IR.rev <- -1*my.data$male.IR

# Mean-centre variables
# Date & incubation duration - though incub isn't used
my.data$lay.date.C <- scale(my.data$lay.date, center = TRUE, scale = FALSE)
my.data$incub.dur.C <- scale(my.data$incub.dur.1, center = TRUE, scale = FALSE)
# Female genetics
my.data$female.H.C <- scale(my.data$female.H, center = TRUE, scale = FALSE)
my.data$female.SH.C <- scale(my.data$female.SH, center = TRUE, scale = FALSE)
my.data$female.HL.rev.C <- scale(my.data$female.HL.rev, center = TRUE, scale = FALSE)
my.data$female.IR.rev.C <- scale(my.data$female.IR.rev, center = TRUE, scale = FALSE)
# Male genetics - though this is not used
my.data$male.H.C <- scale(my.data$male.H, center = TRUE, scale = FALSE)
my.data$male.SH.C <- scale(my.data$male.SH, center = TRUE, scale = FALSE)
my.data$male.HL.rev.C <- scale(my.data$male.HL.rev, center = TRUE, scale = FALSE)
my.data$male.IR.rev.C <- scale(my.data$male.IR.rev, center = TRUE, scale = FALSE)
# Similarity/relatedness - though this is not used
my.data$pair.QGt.C <- scale(my.data$pair.QGt, center = TRUE, scale = FALSE)
my.data$sim.avg.C <- scale(my.data$sim.avg, center = TRUE, scale = FALSE)

# Make quadratic variables
my.data$lay.date.C.SQ <- my.data$lay.date.C^2
my.data$incub.dur.C.SQ <- my.data$incub.dur.C^2
#
my.data$female.H.C.SQ <- my.data$female.H.C^2
my.data$female.SH.C.SQ <- my.data$female.SH.C^2
my.data$female.HL.rev.C.SQ <- my.data$female.HL.rev.C^2
my.data$female.IR.rev.C.SQ <- my.data$female.IR.rev.C^2
#
my.data$male.H.C.SQ <- my.data$male.H.C^2
my.data$male.SH.C.SQ <- my.data$male.SH.C^2
my.data$male.HL.rev.C.SQ <- my.data$male.HL.rev.C^2
my.data$male.IR.rev.C.SQ <- my.data$male.IR.rev.C^2
#
my.data$pair.QGt.C.SQ <- my.data$pair.QGt.C^2
my.data$sim.avg.C.SQ <- my.data$sim.avg.C^2

names(my.data)
str(my.data)
#--------------------------------------------------------------------------------------------

###########################################################################################
###########################################################################################
##########   ~~~~~~~~~~~~~~~~~~~~~~~~~~~~   ###############################################
##########     MAIN MODELS - EGG NUMBER     ###############################################
##########   ~~~~~~~~~~~~~~~~~~~~~~~~~~~~   ###############################################
###########################################################################################

#--------------------------------------------------------------------------------------------
## Without controlling for anything else

# Null model
EGGNO.1.null <- lmer(eggs.laid ~ 1 + (1|female.id), 
	data = my.data, REML = FALSE, na.action = na.fail)

# Linear multilocus heterozygosity, as standardised heterozygosity (SH)
EGGNO.1.MLH <- lmer(eggs.laid ~ female.SH.C + (1|female.id), 
	data = my.data, REML = FALSE, na.action = na.fail)

# Quadratic
EGGNO.1.MLH.SQ <- lmer(eggs.laid ~ female.SH.C + female.SH.C.SQ + (1|female.id), 
	data = my.data, REML = FALSE, na.action = na.fail)

# Summaries, and ANOVAs against null
summary(EGGNO.1.MLH)
anova(EGGNO.1.null, EGGNO.1.MLH)

summary(EGGNO.1.MLH.SQ)
anova(EGGNO.1.null, EGGNO.1.MLH.SQ)

# AICc comparison
AICc(EGGNO.1.null, EGGNO.1.MLH, EGGNO.1.MLH.SQ)

## ALL VERY NON-SIG
#--------------------------------------------------------------------------------------------


#--------------------------------------------------------------------------------------------
## Control for body size

# Drop rows that don't have CCL data
CCL.data <- subset(my.data, CCL != "NA")

# Null model
EGGNO.2.0 <- lmer(eggs.laid ~ 1 + (1|female.id), data = CCL.data, REML = FALSE, na.action = na.fail)

# CCL model
EGGNO.2.CCL <- lmer(eggs.laid ~ CCL + (1|female.id), data = CCL.data, REML = FALSE, na.action = na.fail)

# Compare with ANOVA
anova(EGGNO.2.0, EGGNO.2.CCL)
# P < 0.001


# Examine clutch size-body size relationship
# Summary of model
(CCL.model <- summary(EGGNO.2.CCL))

# Plot raw data
plot(eggs.laid ~ CCL, data = CCL.data,
	xlab = "Female curved carapace length (cm)",
	ylab = "Clutch size",
	xlim = c(75,95),
	ylim = c(50,250),
	mgp = c(2.7,0.9,0), cex.lab = 1.2, las = 1,
	xaxt = "n", yaxt = "n")

axis(side = 1, at = seq(74,96), labels = FALSE)
axis(side = 1)

axis(side = 2, at = seq(50,260,10), labels = FALSE)
axis(side = 2, las = 1)

# Make data for simple straight line
CCL.line <- data.frame(CCL = c(min(CCL.data$CCL), max(CCL.data$CCL)))
c <- coefficients(CCL.model)["(Intercept)","Estimate"]
b <- coefficients(CCL.model)["CCL","Estimate"]
CCL.line$eggs.laid <- b*CCL.line$CCL + c

# Plot the line
lines(eggs.laid~CCL, data=CCL.line)
#--------------------------------------------------------------------------------------------


#--------------------------------------------------------------------------------------------
# ACTUAL HFC TEST
#  - i.e. controlling for CCL

# Linear MLH
EGGNO.2.MLH <- lmer(eggs.laid ~ CCL + female.SH.C + (1|female.id), 
	data = CCL.data, REML = FALSE, na.action = na.fail)

# Quadratic MLH
EGGNO.2.MLH.SQ <- lmer(eggs.laid ~ CCL + female.SH.C + female.SH.C.SQ + (1|female.id), 
	data = CCL.data, REML = FALSE, na.action = na.fail)

# Summaries and ANOVAs
summary(EGGNO.2.MLH)
anova(EGGNO.2.CCL, EGGNO.2.MLH)

summary(EGGNO.2.MLH.SQ)
anova(EGGNO.2.CCL, EGGNO.2.MLH.SQ)
anova(EGGNO.2.MLH, EGGNO.2.MLH.SQ)

# AICc comparisons
AICc(EGGNO.2.CCL, EGGNO.2.MLH, EGGNO.2.MLH.SQ)

## NO HFC, but body size very sig
#--------------------------------------------------------------------------------------------


#--------------------------------------------------------------------------------------------
# Check CCL v. MLH

# Reduce to non-repeats, and do with lm
CCL.data.noDups <- CCL.data[!duplicated(CCL.data$female.id),]

# Models - null and MLH
CCL.MLH.0 <- lm(CCL ~ 1, data = CCL.data.noDups, na.action = na.fail)
CCL.MLH.1 <- lm(CCL ~ female.SH.C, data = CCL.data.noDups, na.action = na.fail)

# Compare models
summary(CCL.MLH.0)
summary(CCL.MLH.1)
anova(CCL.MLH.0, CCL.MLH.1)

AICc(CCL.MLH.0, CCL.MLH.1)

## Not significant
#--------------------------------------------------------------------------------------------


#--------------------------------------------------------------------------------------------
## Try single-locus HFC (SLH)

# Full model
EGGNO.2.SLH <- lmer(eggs.laid ~ CCL + fem.loc01.S + fem.loc02.S + fem.loc03.S + fem.loc04.S + fem.loc05.S + fem.loc06.S + fem.loc07.S + fem.loc08.S + fem.loc09.S + fem.loc10.S 
		+ fem.loc11.S + fem.loc12.S + fem.loc13.S + fem.loc14.S + fem.loc15.S + fem.loc16.S + fem.loc17.S + fem.loc18.S + fem.loc19.S + fem.loc20.S 
		+ fem.loc21.S + fem.loc22.S + fem.loc23.S + fem.loc24.S + fem.loc25.S + fem.loc26.S + fem.loc27.S + fem.loc28.S + fem.loc29.S + fem.loc30.S 
		+ fem.loc31.S + fem.loc32.S 
		+ (1|female.id), data = CCL.data, REML = FALSE, na.action = na.fail)

# ANOVA
anova(EGGNO.2.MLH, EGGNO.2.SLH)	# P = 0.081, df = 5,36

## Not sig, though near
#--------------------------------------------------------------------------------------------


#--------------------------------------------------------------------------------------------
## TRY ALTERNATIVE MLH METRICS

### Homozygosity-by-loci (HL) ###
# Linear
EGGNO.2.HL <- lmer(eggs.laid ~ CCL + female.HL.rev.C + (1|female.id),
	data = CCL.data, REML = FALSE, na.action = na.fail)

# Quadratic
EGGNO.2.HL.SQ <- lmer(eggs.laid ~ CCL + female.HL.rev.C + female.HL.rev.C.SQ + (1|female.id),
	data = CCL.data, REML = FALSE, na.action = na.fail)

# Compare models
anova(EGGNO.2.CCL, EGGNO.2.HL)
anova(EGGNO.2.CCL, EGGNO.2.HL.SQ)
anova(EGGNO.2.HL, EGGNO.2.HL.SQ)
anova(EGGNO.2.HL, EGGNO.2.SLH)
AICc(EGGNO.2.CCL, EGGNO.2.HL, EGGNO.2.HL.SQ)
####


### Internal relatedness (IR) ###
# Linear
EGGNO.2.IR <- lmer(eggs.laid ~ CCL + female.IR.rev.C + (1|female.id),
	data = CCL.data, REML = FALSE, na.action = na.fail)

# Quadratic
EGGNO.2.IR.SQ <- lmer(eggs.laid ~ CCL + female.IR.rev.C + female.IR.rev.C.SQ + (1|female.id),
	data = CCL.data, REML = FALSE, na.action = na.fail)

# Compare models
anova(EGGNO.2.CCL, EGGNO.2.IR)
anova(EGGNO.2.CCL, EGGNO.2.IR.SQ)
anova(EGGNO.2.IR, EGGNO.2.IR.SQ)
anova(EGGNO.2.IR, EGGNO.2.SLH)
AICc(EGGNO.2.CCL, EGGNO.2.IR, EGGNO.2.IR.SQ)
####

### ALL VERY NON-SIGNIFICANT ###
#--------------------------------------------------------------------------------------------


#--------------------------------------------------------------------------------------------
## Test for effects of date, on top of CCL

# CCL-only
EGGNO.3.null <- lmer(eggs.laid ~ CCL + (1|female.id), data = CCL.data, REML = FALSE, na.action = na.fail)

# Linear date effect
EGGNO.3.date1 <- lmer(eggs.laid ~ CCL + lay.date.C + (1|female.id), 
	data = CCL.data, REML = FALSE, na.action = na.fail)

# Quadratic data effect
EGGNO.3.date2 <- lmer(eggs.laid ~ CCL + lay.date.C + lay.date.C.SQ + (1|female.id), 
	data = CCL.data, REML = FALSE, na.action = na.fail)

# Compare models
anova(EGGNO.3.null, EGGNO.3.date1)
anova(EGGNO.3.null, EGGNO.3.date2)
AICc(EGGNO.3.null, EGGNO.3.date1, EGGNO.3.date2)

## No effect of lay date on egg number
#--------------------------------------------------------------------------------------------


#--------------------------------------------------------------------------------------------
# Supplementary tests and quality controls

# Nakagawa R2 for CCL and null models
rsquared.lme(list(EGGNO.2.0, EGGNO.2.CCL))


# Normality of CCL model residuals
# Could try structures better suited to counts
#  - but residuals have left-hand skew rather than the right-hand skew these models normally involve
#  - it is easier for a female to lay an abnormally small clutch than an abnormally large clutch

shapiro.test(residuals(EGGNO.2.CCL))		# P < 0.0001!!!
skewness(residuals(EGGNO.2.CCL))			# -0.92 - not really that bad
kurtosis(residuals(EGGNO.2.CCL))			# 6.08 - pretty bad
hist(residuals(EGGNO.2.CCL))				# obvious 'spike' and one LH outlier

# Do with Poisson, just to be sure all is OK
EGGNO.2.CCL.pois <- glmer(eggs.laid ~ scale(CCL) + (1|female.id), data = CCL.data, family="poisson", na.action = na.fail)
summary(EGGNO.2.CCL.pois)
hist(residuals(EGGNO.2.CCL.pois))			# Not great
skewness(residuals(EGGNO.2.CCL.pois))		# -1.49 - worse than Gaussian!
kurtosis(residuals(EGGNO.2.CCL.pois))		# 12.60 - worse than Gaussian!

# Do with glmer.nb
EGGNO.2.CCL.nb <- glmer.nb(eggs.laid ~ scale(CCL) + (1|female.id), data = CCL.data, na.action = na.fail)
summary(EGGNO.2.CCL.nb)
hist(residuals(EGGNO.2.CCL.nb))
skewness(residuals(EGGNO.2.CCL.nb))			# -1.60 - even worse than Poisson!
kurtosis(residuals(EGGNO.2.CCL.nb))			# 8.29 - worse than Gaussian but better than Pois

# Try sqrt transformation
EGGNO.2.CCL.sqrt <- lmer(sqrt(eggs.laid) ~ scale(CCL) + (1|female.id), data = CCL.data, REML=FALSE, na.action = na.fail)
hist(residuals(EGGNO.2.CCL.sqrt))			# Still bad
skewness(residuals(EGGNO.2.CCL.sqrt))		# -1.42 - worse than Gaussian, but better than others
kurtosis(residuals(EGGNO.2.CCL.sqrt))		# 7.96 - worse than Gaussian but better than others

# SUCK IT UP AND STICK WITH LINEAR - the left-hand skew is a pain to address, and the one outlier is the main issue
#--------------------------------------------------------------------------------------------
