# Heterozygosity-fitness correlations against success of eggs
#  - ALL FEMALES, i.e. including ones not in the tests involving reconstructed males
# Three fitness measures - fertility, hatching, and emergence
# MLH and SLH tests are both present in this script
# Tests of female heterozygosity against eggs laid are in another script
# Tests of MP nests against SP nests are in another script

# Revised 2017-08-01 for Dryad
#  - tidied, streamlined, and better annotated

#--------------------------------------------------------------------------------------------
# Clear R
rm(list = ls())

# Load necessary packages
library(MASS)
library(lme4)
library(lmerTest)
library(moments)
library(MuMIn)
#--------------------------------------------------------------------------------------------


#--------------------------------------------------------------------------------------------
####  BRING IN DATA  ########

# Set WD
setwd("FILEPATH")

# Read datafile
data.FULL <- read.csv("00_HFC_extendedData.csv")
#--------------------------------------------------------------------------------------------


#--------------------------------------------------------------------------------------------
## Code for Nakagawa Rsq for LMM
## http://jslefche.wordpress.com/2013/03/13/r2-for-linear-mixed-effects-models/
## Updated by us, as original was written for lme4 in R v2

rsquared.lme=function(modlist) {
  #Iterate over each model in the list
  do.call(rbind,lapply(modlist,function(i) {
    #For models fit using lm
    if(class(i)=="lm") {
      Rsquared.mat=data.frame(Class=class(i),Marginal=summary(i)$r.squared,
                              Conditional=NA,AIC=AIC(i)) } 
    #For models fit using lme4
    else if(class(i)=="mer" | class(i)=="merMod" | class(i)=="merLmerTest") {
      #Get variance of fixed effects by multiplying coefficients by design matrix
      VarF=var(as.vector(fixef(i) %*% t(i@X))) 
      #Get variance of random effects by extracting variance components
      VarRand=colSums(do.call(rbind,lapply(VarCorr(i),function(j) j[1])))
      #Get residual variance
      VarResid=attr(VarCorr(i),"sc")^2
      #Calculate marginal R-squared (fixed effects/total variance)
      Rm=VarF/(VarF+VarRand+VarResid)
      #Calculate conditional R-squared (fixed effects+random effects/total variance)
      Rc=(VarF+VarRand)/(VarF+VarRand+VarResid)
      #Bind R^2s into a matrix and return with AIC values
      Rsquared.mat=data.frame(Class=class(i),Marginal=Rm,Conditional=Rc,
                              AIC=AIC(update(i,REML=F))) } 
    #For models fit using NEWER VERSION of lme4 WITH lmerTest
    else if(class(i)=="lmerMod" | class(i)=="merModLmerTest") {
      #Get variance of fixed effects by multiplying coefficients by design matrix
      VarF=var(as.vector(fixef(i) %*% t(i@pp$X))) 
      #Get variance of random effects by extracting variance components
      VarRand=colSums(do.call(rbind,lapply(VarCorr(i),function(j) j[1])))
      #Get residual variance
      VarResid=attr(VarCorr(i),"sc")^2
      #Calculate marginal R-squared (fixed effects/total variance)
      Rm=VarF/(VarF+VarRand+VarResid)
      #Calculate conditional R-squared (fixed effects+random effects/total variance)
      Rc=(VarF+VarRand)/(VarF+VarRand+VarResid)
      #Bind R^2s into a matrix and return with AIC values
      Rsquared.mat=data.frame(Class=class(i),Marginal=Rm,Conditional=Rc,
                              AIC=AIC(update(i,REML=F))) } 
    #For model fit using nlme  
    else if(class(i)=="lme") {
      #Get design matrix of fixed effects from model
      Fmat=model.matrix(eval(i$call$fixed)[-2],i$data)
      #Get variance of fixed effects by multiplying coefficients by design matrix
      VarF=var(as.vector(fixef(i) %*% t(Fmat)))
      #Get variance of random effects by extracting variance components
      VarRand=sum(suppressWarnings(as.numeric(VarCorr(i)[rownames(VarCorr(i))!=
                                                           "Residual",1])),na.rm=T)
      #Get residual variance
      VarResid=as.numeric(VarCorr(i)[rownames(VarCorr(i))=="Residual",1])
      #Calculate marginal R-squared (fixed effects/total variance)
      Rm=VarF/(VarF+VarRand+VarResid)
      #Calculate conditional R-squared (fixed effects+random effects/total variance)
      Rc=(VarF+VarRand)/(VarF+VarRand+VarResid)
      #Bind R^2s into a matrix and return with AIC values
      Rsquared.mat=data.frame(Class=class(i),Marginal=Rm,Conditional=Rc,
                              AIC=AIC(update(i,method="ML")))
    } else { print("Function requires models of class lm, lme, mer, or merMod") 
    } } ) ) }
#  rsquared.lme(list( ENTER MODEL NAMES HERE ))
#--------------------------------------------------------------------------------------------


#--------------------------------------------------------------------------------------------
##  Collinearity diagnostics

vif.mer <- function (fit) {
  ## adapted from rms::vif
  
  v <- vcov(fit)
  nam <- names(fixef(fit))
  
  ## exclude intercepts
  ns <- sum(1 * (nam == "Intercept" | nam == "(Intercept)"))
  if (ns > 0) {
    v <- v[-(1:ns), -(1:ns), drop = FALSE]
    nam <- nam[-(1:ns)]
  }
  
  d <- diag(v)^0.5
  v <- diag(solve(v/(d %o% d)))
  names(v) <- nam
  v
}

kappa.mer <- function (fit,
                       scale = TRUE, center = FALSE,
                       add.intercept = TRUE,
                       exact = FALSE) {
  X <- fit@pp$X
  nam <- names(fixef(fit))
  
  ## exclude intercepts
  nrp <- sum(1 * (nam == "(Intercept)"))
  if (nrp > 0) {
    X <- X[, -(1:nrp), drop = FALSE]
    nam <- nam[-(1:nrp)]
  }
  
  if (add.intercept) {
    X <- cbind(rep(1), scale(X, scale = scale, center = center))
    kappa(X, exact = exact)
  } else {
    kappa(scale(X, scale = scale, center = scale), exact = exact)
  }
}
#--------------------------------------------------------------------------------------------


#--------------------------------------------------------------------------------------------
####  EXAMINE/REFINE DATA  ########
# Examine
str(data.FULL, list.len = 220)
names(data.FULL)
nrow(data.FULL)

# Columns for focal analyses
colList <- c("FERTILE", "HATCHED", "TO.SEA", "year", "pair.id", "female.id", "male.id", 
	"male.offspringtyped", "female.SH", "female.HL", "female.IR", 
	"pair.QGt", "sim.avg", "lay.date", "incub.dur.1", "eggs.laid", "CCL", 
	"fem.loc01.S", "fem.loc02.S", "fem.loc03.S", "fem.loc04.S", "fem.loc05.S", "fem.loc06.S", 
	"fem.loc07.S", "fem.loc08.S", "fem.loc09.S", "fem.loc10.S", "fem.loc11.S", "fem.loc12.S", 
	"fem.loc13.S", "fem.loc14.S", "fem.loc15.S", "fem.loc16.S", "fem.loc17.S", "fem.loc18.S", 
	"fem.loc19.S", "fem.loc20.S", "fem.loc21.S", "fem.loc22.S", "fem.loc23.S", "fem.loc24.S", 
	"fem.loc25.S", "fem.loc26.S", "fem.loc27.S", "fem.loc28.S", "fem.loc29.S", "fem.loc30.S", 
	"fem.loc31.S", "fem.loc32.S")

# Get subset for these analyses
my.data <- data.FULL[!is.na(data.FULL$female.SH),colList]
str(my.data, list.len = 220)

# Redefine numeric variables that need to be factors
my.data$year <- factor(my.data$year)
my.data$pair.id <- factor(my.data$pair.id)
my.data$female.id <- factor(my.data$female.id)
my.data$male.id <- factor(my.data$male.id)

# check structure again
str(my.data)
#--------------------------------------------------------------------------------------------


#--------------------------------------------------------------------------------------------
# CREATE NEW VARIABLES
#  - standardising directions of alternative H metrics
#  - mean-centering the genetic predictors
#  - make quadratic variables

# Reverse HL & IR - though these aren't used in the script, a user could easily run them
my.data$female.HL.rev <- 1-my.data$female.HL
my.data$female.IR.rev <- -1*my.data$female.IR

# Mean-centre variables
# Date & incubation duration - though incub isn't used
my.data$lay.date.C <- scale(my.data$lay.date, center = TRUE, scale = FALSE)
my.data$incub.dur.C <- scale(my.data$incub.dur.1, center = TRUE, scale = FALSE)
#
my.data$female.H.C <- scale(my.data$female.H, center = TRUE, scale = FALSE)
my.data$female.SH.C <- scale(my.data$female.SH, center = TRUE, scale = FALSE)
my.data$female.HL.rev.C <- scale(my.data$female.HL.rev, center = TRUE, scale = FALSE)
my.data$female.IR.rev.C <- scale(my.data$female.IR.rev, center = TRUE, scale = FALSE)

# Make quadratic variables
my.data$lay.date.C.SQ <- my.data$lay.date.C^2
my.data$incub.dur.C.SQ <- my.data$incub.dur.C^2
#
my.data$female.H.C.SQ <- my.data$female.H.C^2
my.data$female.SH.C.SQ <- my.data$female.SH.C^2
my.data$female.HL.rev.C.SQ <- my.data$female.HL.rev.C^2
my.data$female.IR.rev.C.SQ <- my.data$female.IR.rev.C^2

names(my.data)
str(my.data)
#--------------------------------------------------------------------------------------------


#--------------------------------------------------------------------------------------------
######    TEST - Het v egg fertility (FERTILE)     ################################################

## Remove NAs from FERTILE, incub.dur.1
FERTILE.data <- my.data[!is.na(my.data$FERTILE),]
FERTILE.data <- FERTILE.data[!is.na(FERTILE.data$incub.dur.1),]

## Blank model
FERTILE.0 <- lmer(FERTILE ~ 1 + (1|female.id), REML = FALSE, 
	data = FERTILE.data, na.action = na.fail)

## Functional null (note: no value in adding incub.SQ - P = 0.333)
FERTILE.null <- lmer(FERTILE ~ lay.date.C + lay.date.C.SQ + incub.dur.C + (1|female.id), 
	REML = FALSE, data = FERTILE.data, na.action = na.fail)

anova(FERTILE.0, FERTILE.null)
AICc(FERTILE.0, FERTILE.null)
# Date and incubation still justified
summary(FERTILE.null)


## HFC - linear
FERTILE.HFC.1 <- lmer(FERTILE ~ lay.date.C + lay.date.C.SQ + incub.dur.C + female.SH.C + (1|female.id), 
	REML = FALSE, data = FERTILE.data, na.action = na.fail)

anova(FERTILE.null, FERTILE.HFC.1)		# P = 0.967
AICc(FERTILE.null, FERTILE.HFC.1)
summary(FERTILE.HFC.1)				# 130 nests, 67 females


## HFC - quadratic
FERTILE.HFC.2 <- lmer(FERTILE ~ lay.date.C + lay.date.C.SQ + incub.dur.C + female.SH.C + female.SH.C.SQ + (1|female.id), 
	REML = FALSE, data = FERTILE.data, na.action = na.fail)

anova(FERTILE.null, FERTILE.HFC.2)		# P = 0.792
AICc(FERTILE.null, FERTILE.HFC.2)
summary(FERTILE.HFC.2)

## SLH HFC
FERTILE.SLH <- lmer(FERTILE ~ lay.date.C + lay.date.C.SQ + incub.dur.C 
		+ fem.loc01.S + fem.loc02.S + fem.loc03.S + fem.loc04.S + fem.loc05.S + fem.loc06.S + fem.loc07.S + fem.loc08.S + fem.loc09.S + fem.loc10.S 
		+ fem.loc11.S + fem.loc12.S + fem.loc13.S + fem.loc14.S + fem.loc15.S + fem.loc16.S + fem.loc17.S + fem.loc18.S + fem.loc19.S + fem.loc20.S 
		+ fem.loc21.S + fem.loc22.S + fem.loc23.S + fem.loc24.S + fem.loc25.S + fem.loc26.S + fem.loc27.S + fem.loc28.S + fem.loc29.S + fem.loc30.S 
		+ fem.loc31.S + fem.loc32.S + (1|female.id), REML=FALSE, data = FERTILE.data, na.action = na.fail)

anova(FERTILE.HFC.1, FERTILE.SLH)		# P = 0.402


# quality control
## collinearity diagnostics
vif.mer(FERTILE.null)		# all between 1.01 & 1.13
kappa.mer(FERTILE.null)		# 2.36


## Nakagawa R2
rsquared.lme(list(FERTILE.0, FERTILE.null, FERTILE.HFC.1, FERTILE.HFC.2))


## Normality of residuals
shapiro.test(residuals(FERTILE.null))	# P = 0.162
skewness(residuals(FERTILE.null))		# -0.276
kurtosis(residuals(FERTILE.null))		# 2.772

hist(residuals(FERTILE.null))
#--------------------------------------------------------------------------------------------


#--------------------------------------------------------------------------------------------
#@@@@@@@@@    Next on 'HATCHED'    @@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@

## Remove NAs from HATCHED, incub.dur.1
HATCHED.data <- my.data[!is.na(my.data$HATCHED),]
HATCHED.data <- HATCHED.data[!is.na(HATCHED.data$incub.dur.1),]

## Blank model
HATCHED.0 <- lmer(HATCHED ~ 1 + (1|female.id), REML = FALSE, 
	data = HATCHED.data, na.action = na.fail)

## Functional null (note: no value in adding incub.SQ - P = 0.333)
HATCHED.null <- lmer(HATCHED ~ lay.date.C + lay.date.C.SQ + incub.dur.C + (1|female.id), 
	REML = FALSE, data = HATCHED.data, na.action = na.fail)

anova(HATCHED.0, HATCHED.null)
AICc(HATCHED.0, HATCHED.null)
# Date and incubation still important


## HFC - linear
HATCHED.HFC.1 <- lmer(HATCHED ~ lay.date.C + lay.date.C.SQ + incub.dur.C + female.SH.C + (1|female.id), 
	REML = FALSE, data = HATCHED.data, na.action = na.fail)

anova(HATCHED.null, HATCHED.HFC.1)		# P = 0.542
AICc(HATCHED.null, HATCHED.HFC.1)
summary(HATCHED.HFC.1)				# 130 nests, 67 females


## HFC - quadratic
HATCHED.HFC.2 <- lmer(HATCHED ~ lay.date.C + lay.date.C.SQ + incub.dur.C + female.SH.C + female.SH.C.SQ + (1|female.id), 
	REML = FALSE, data = HATCHED.data, na.action = na.fail)

anova(HATCHED.null, HATCHED.HFC.2)		# P = 0.453
AICc(HATCHED.null, HATCHED.HFC.2)
summary(HATCHED.HFC.2)


## SLH HFC
HATCHED.SLH <- lmer(HATCHED ~ lay.date.C + lay.date.C.SQ + incub.dur.C 
		+ fem.loc01.S + fem.loc02.S + fem.loc03.S + fem.loc04.S + fem.loc05.S + fem.loc06.S + fem.loc07.S + fem.loc08.S + fem.loc09.S + fem.loc10.S 
		+ fem.loc11.S + fem.loc12.S + fem.loc13.S + fem.loc14.S + fem.loc15.S + fem.loc16.S + fem.loc17.S + fem.loc18.S + fem.loc19.S + fem.loc20.S 
		+ fem.loc21.S + fem.loc22.S + fem.loc23.S + fem.loc24.S + fem.loc25.S + fem.loc26.S + fem.loc27.S + fem.loc28.S + fem.loc29.S + fem.loc30.S 
		+ fem.loc31.S + fem.loc32.S + (1|female.id), 
	REML = FALSE, data = HATCHED.data, na.action = na.fail)

anova(HATCHED.HFC.1, HATCHED.SLH)		# P = 0.526


# quality control
## collinearity diagnostics
vif.mer(HATCHED.null)		# all between 1.01 & 1.12
kappa.mer(HATCHED.null)		# 2.36


## Nakagawa R2
rsquared.lme(list(HATCHED.0, HATCHED.null, HATCHED.HFC.1, HATCHED.HFC.2))


## normality of residuals
shapiro.test(residuals(HATCHED.null))		# P = 0.158
skewness(residuals(HATCHED.null))			# -0.083
kurtosis(residuals(HATCHED.null))			# 2.523

hist(residuals(HATCHED.null))
#--------------------------------------------------------------------------------------------


#--------------------------------------------------------------------------------------------
#@@@@@@@@@    Next on 'TO.SEA'    @@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@
# This is the focal fitness response for the paper

## Remove NAs from TO.SEA, incub.dur.1
TO.SEA.data <- my.data[!is.na(my.data$TO.SEA),]
TO.SEA.data <- TO.SEA.data[!is.na(TO.SEA.data$incub.dur.1),]

## Blank model
TO.SEA.0 <- lmer(TO.SEA ~ 1 + (1|female.id), REML = FALSE, 
	data = TO.SEA.data, na.action = na.fail)

## Functional null (note: no value in adding incub.SQ - P = 0.333)
TO.SEA.null <- lmer(TO.SEA ~ lay.date.C + lay.date.C.SQ + incub.dur.C + (1|female.id), 
	REML = FALSE, data = TO.SEA.data, na.action = na.fail)

anova(TO.SEA.0, TO.SEA.null)
AICc(TO.SEA.0, TO.SEA.null)
summary(TO.SEA.null)
# Date and incubation still important


## HFC - linear
TO.SEA.HFC.1 <- lmer(TO.SEA ~ lay.date.C + lay.date.C.SQ + incub.dur.C + female.SH.C + (1|female.id), 
	REML = FALSE, data = TO.SEA.data, na.action = na.fail)

anova(TO.SEA.null, TO.SEA.HFC.1)		# P = 0.392
AICc(TO.SEA.null, TO.SEA.HFC.1)
summary(TO.SEA.HFC.1)				# 129 nests, 67 females


## HFC - quadratic
TO.SEA.HFC.2 <- lmer(TO.SEA ~ lay.date.C + lay.date.C.SQ + incub.dur.C + female.SH.C + female.SH.C.SQ + (1|female.id), 
	REML = FALSE, data = TO.SEA.data, na.action = na.fail)

anova(TO.SEA.null, TO.SEA.HFC.2)		# P = 0.370
AICc(TO.SEA.null, TO.SEA.HFC.2)
summary(TO.SEA.HFC.2)


## SLH HFC
TO.SEA.SLH <- lmer(TO.SEA ~ lay.date.C + lay.date.C.SQ + incub.dur.C 
		+ fem.loc01.S + fem.loc02.S + fem.loc03.S + fem.loc04.S + fem.loc05.S + fem.loc06.S + fem.loc07.S + fem.loc08.S + fem.loc09.S + fem.loc10.S 
		+ fem.loc11.S + fem.loc12.S + fem.loc13.S + fem.loc14.S + fem.loc15.S + fem.loc16.S + fem.loc17.S + fem.loc18.S + fem.loc19.S + fem.loc20.S 
		+ fem.loc21.S + fem.loc22.S + fem.loc23.S + fem.loc24.S + fem.loc25.S + fem.loc26.S + fem.loc27.S + fem.loc28.S + fem.loc29.S + fem.loc30.S 
		+ fem.loc31.S + fem.loc32.S + (1|female.id), 
	REML = FALSE, data = TO.SEA.data, na.action = na.fail)

anova(TO.SEA.HFC.1, TO.SEA.SLH)		# P = 0.674


# quality control
## collinearity diagnostics
vif.mer(TO.SEA.null)		# all between 1.02 & 1.11
kappa.mer(TO.SEA.null)		# 2.45


## Nakagawa R2
rsquared.lme(list(TO.SEA.0, TO.SEA.null, TO.SEA.HFC.1, TO.SEA.HFC.2))


## normality of residuals
shapiro.test(residuals(TO.SEA.null))		# P = 0.180
skewness(residuals(TO.SEA.null))			# -0.183
kurtosis(residuals(TO.SEA.null))			# 2.515

hist(residuals(TO.SEA.null))
#--------------------------------------------------------------------------------------------