# Heterozygosity-fitness correlations against success of eggs
#  FOCUS ON SINGLE-LOCUS EFFECTS
# Three fitness measures - fertility, hatching, and emergence
# This file compares MLH and SLH models
# Main MLH models are in another script
# Tests of female heterozygosity against eggs laid are in another file
# Tests of MP nests against SP nests are in another R-file

# Revised 2017-08-01 for Dryad
#  - tidied, streamlined, and better annotated

#--------------------------------------------------------------------------------------------
# Clear R
rm(list = ls())

# Load necessary packages
library(MASS)
library(lme4)
#library(lmerTest)
library(moments)
library(MuMIn)
#--------------------------------------------------------------------------------------------


#--------------------------------------------------------------------------------------------
####  BRING IN DATA  ########

# Set WD
setwd("FILEPATH")

# Read datafile
data.FULL <- read.csv("00_HFC_extendedData.csv")

# Examine
str(data.FULL, list.len = 220)
names(data.FULL)
nrow(data.FULL)

# Columns for focal analyses
colList <- c("het.v.success", "FERTILE", "HATCHED", "TO.SEA", "year", "pair.id", "female.id", "male.id", "male.offspringtyped", 
	"female.SH", "male.SH", "pair.QGt", "sim.avg", "lay.date", "incub.dur.1", "eggs.laid", "CCL",
	"mal.loc01.S", "mal.loc02.S", "mal.loc03.S", "mal.loc04.S", "mal.loc05.S", "mal.loc06.S", "mal.loc07.S", "mal.loc08.S", 
		"mal.loc09.S", "mal.loc10.S", "mal.loc11.S", "mal.loc12.S", "mal.loc13.S", "mal.loc14.S", "mal.loc15.S", "mal.loc16.S", 
		"mal.loc17.S", "mal.loc18.S", "mal.loc19.S", "mal.loc20.S", "mal.loc21.S", "mal.loc22.S", "mal.loc23.S", "mal.loc24.S", 
		"mal.loc25.S", "mal.loc26.S", "mal.loc27.S", "mal.loc28.S", "mal.loc29.S", "mal.loc30.S", "mal.loc31.S", "mal.loc32.S",
	"fem.loc01.S", "fem.loc02.S", "fem.loc03.S", "fem.loc04.S", "fem.loc05.S", "fem.loc06.S", "fem.loc07.S", "fem.loc08.S", 
		"fem.loc09.S", "fem.loc10.S",	"fem.loc11.S", "fem.loc12.S", "fem.loc13.S", "fem.loc14.S", "fem.loc15.S", "fem.loc16.S", 
		"fem.loc17.S", "fem.loc18.S", "fem.loc19.S", "fem.loc20.S",	"fem.loc21.S", "fem.loc22.S", "fem.loc23.S", "fem.loc24.S", 
		"fem.loc25.S", "fem.loc26.S", "fem.loc27.S", "fem.loc28.S", "fem.loc29.S", "fem.loc30.S",	"fem.loc31.S", "fem.loc32.S",
	"sim.loc01", "sim.loc02", "sim.loc03", "sim.loc04", "sim.loc05", "sim.loc06", "sim.loc07", "sim.loc08", "sim.loc09", "sim.loc10",
		"sim.loc11", "sim.loc12", "sim.loc13", "sim.loc14", "sim.loc15", "sim.loc16", "sim.loc17", "sim.loc18", 
		"sim.loc19", "sim.loc20","sim.loc21", "sim.loc22", "sim.loc23", "sim.loc24", "sim.loc25", "sim.loc26", 
		"sim.loc27", "sim.loc28", "sim.loc29", "sim.loc30", "sim.loc31", "sim.loc32")

# make subset for use in paper
my.data <- data.FULL[data.FULL$het.v.success == "Y", colList]
str(my.data, list.len = 220)


# Redefine numerical variables that need to be factors
my.data$year <- factor(my.data$year)
my.data$pair.id <- factor(my.data$pair.id)
my.data$female.id <- factor(my.data$female.id)
my.data$male.id <- factor(my.data$male.id)

# Now that MP nests have been stripped away, convert 'male.offspringtyped' to integer
my.data$male.offspringtyped <- as.integer(my.data$male.offspringtyped)

# check structure again
str(my.data, list.len = 220)
#--------------------------------------------------------------------------------------------


#--------------------------------------------------------------------------------------------
# CREATE NEW VARIABLES
#  - mean-centering the genetic predictors
#  - make quadratic variables

# Mean-centre variables
# Date & incubation duration - though incub isn't used
my.data$lay.date.C <- scale(my.data$lay.date, center = TRUE, scale = FALSE)
my.data$incub.dur.C <- scale(my.data$incub.dur.1, center = TRUE, scale = FALSE)

# Genetics
my.data$female.SH.C <- scale(my.data$female.SH, center = TRUE, scale = FALSE)
my.data$male.SH.C <- scale(my.data$male.SH, center = TRUE, scale = FALSE)
my.data$pair.QGt.C <- scale(my.data$pair.QGt, center = TRUE, scale = FALSE)
my.data$sim.avg.C <- scale(my.data$sim.avg, center = TRUE, scale = FALSE)

# Make quadratic variables
my.data$lay.date.C.SQ <- my.data$lay.date.C^2
my.data$incub.dur.C.SQ <- my.data$incub.dur.C^2
#
my.data$female.SH.C.SQ <- my.data$female.SH.C^2
my.data$male.SH.C.SQ <- my.data$male.SH.C^2
my.data$pair.QGt.C.SQ <- my.data$pair.QGt.C^2
my.data$sim.avg.C.SQ <- my.data$sim.avg.C^2

names(my.data)
str(my.data)
#--------------------------------------------------------------------------------------------


#============================================================================================
######     TEST - Het v egg fertility (FERTILE)      #######################################

# Null model
FERTILE.null <- lmer(FERTILE ~ lay.date.C + lay.date.C.SQ + incub.dur.C + (1|pair.id), 
	REML = FALSE, data = my.data, na.action = na.fail)


#%%%%%%%%%%%%%%%%%%%%%%%%%%%
#%%%%   Male-centred   %%%%%
#%%%%%%%%%%%%%%%%%%%%%%%%%%%

# MLH linear
FERTILE.mal.MLH <- lmer(FERTILE ~ lay.date.C + lay.date.C.SQ + incub.dur.C + male.SH.C + (1|pair.id), 
	REML = FALSE, data = my.data, na.action = na.fail)

# SLH
FERTILE.mal.SLH <- lmer(FERTILE ~ lay.date.C + lay.date.C.SQ + incub.dur.C
		+ mal.loc01.S + mal.loc02.S + mal.loc03.S + mal.loc04.S + mal.loc05.S + mal.loc06.S + mal.loc07.S + mal.loc08.S + mal.loc09.S + mal.loc10.S 
		+ mal.loc11.S + mal.loc12.S + mal.loc13.S + mal.loc14.S + mal.loc15.S + mal.loc16.S + mal.loc17.S + mal.loc18.S + mal.loc19.S + mal.loc20.S 
		+ mal.loc21.S + mal.loc22.S + mal.loc23.S + mal.loc24.S + mal.loc25.S + mal.loc26.S + mal.loc27.S + mal.loc28.S + mal.loc29.S + mal.loc30.S 
		+ mal.loc31.S + mal.loc32.S + (1|pair.id), 
	REML = FALSE, data = my.data, na.action = na.fail)

# MLH quadratic
FERTILE.mal.MLH.SQ <- lmer(FERTILE ~ lay.date.C + lay.date.C.SQ + incub.dur.C
	+ male.SH.C + male.SH.C.SQ + (1|pair.id), 
	REML = FALSE, data = my.data, na.action = na.fail)

# Add female linear
FERTILE.mal.MLH.F <- lmer(FERTILE ~ lay.date.C + lay.date.C.SQ + incub.dur.C
	+ male.SH.C + female.SH.C + (1|pair.id), 
	REML = FALSE, data = my.data, na.action = na.fail)

# Add female interaction
FERTILE.mal.MLH.Fi <- lmer(FERTILE ~ lay.date.C + lay.date.C.SQ + incub.dur.C
	+ male.SH.C + female.SH.C + male.SH.C*female.SH.C + (1|pair.id), 
	REML = FALSE, data = my.data, na.action = na.fail)

# Add pair similarity linear
FERTILE.mal.MLH.S <- lmer(FERTILE ~ lay.date.C + lay.date.C.SQ + incub.dur.C
	+ male.SH.C + pair.QGt.C + (1|pair.id), 
	REML = FALSE, data = my.data, na.action = na.fail)

# Add pair similarity interaction
FERTILE.mal.MLH.Si <- lmer(FERTILE ~ lay.date.C + lay.date.C.SQ + incub.dur.C
	+ male.SH.C + pair.QGt.C + male.SH.C*pair.QGt.C	+ (1|pair.id), 
	REML = FALSE, data = my.data, na.action = na.fail)


## Compare models
anova(FERTILE.null, FERTILE.mal.MLH)		# P = 0.110, df = 6,7
anova(FERTILE.mal.MLH, FERTILE.mal.SLH)		# P = 0.026, df = 7,38
anova(FERTILE.mal.MLH, FERTILE.mal.MLH.SQ)	# P = 0.111, df = 7,8
anova(FERTILE.mal.MLH, FERTILE.mal.MLH.F)		# P = 0.399, df = 7,8
anova(FERTILE.mal.MLH, FERTILE.mal.MLH.S)		# P = 0.021, df = 7,8
anova(FERTILE.mal.MLH, FERTILE.mal.MLH.Fi)	# P = 0.511, df = 7,9
anova(FERTILE.mal.MLH, FERTILE.mal.MLH.Si)	# P = 0.007, df = 7,9

## Which single loci have significant slopes?
summary(FERTILE.mal.SLH)
# Locus 15 (negative)
# Locus 26 (negative)
# Locus 20 (negative)

#~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

#%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
#%%%%   Female-centred   %%%%%
#%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

# MLH linear
FERTILE.fem.MLH <- lmer(FERTILE ~ lay.date.C + lay.date.C.SQ + incub.dur.C + female.SH.C + (1|pair.id), 
	REML = FALSE, data = my.data, na.action = na.fail)

# SLH
FERTILE.fem.SLH <- lmer(FERTILE ~ lay.date.C + lay.date.C.SQ + incub.dur.C
		+ fem.loc01.S + fem.loc02.S + fem.loc03.S + fem.loc04.S + fem.loc05.S + fem.loc06.S + fem.loc07.S + fem.loc08.S + fem.loc09.S + fem.loc10.S 
		+ fem.loc11.S + fem.loc12.S + fem.loc13.S + fem.loc14.S + fem.loc15.S + fem.loc16.S + fem.loc17.S + fem.loc18.S + fem.loc19.S + fem.loc20.S 
		+ fem.loc21.S + fem.loc22.S + fem.loc23.S + fem.loc24.S + fem.loc25.S + fem.loc26.S + fem.loc27.S + fem.loc28.S + fem.loc29.S + fem.loc30.S 
		+ fem.loc31.S + fem.loc32.S + (1|pair.id), 
	REML = FALSE, data = my.data, na.action = na.fail)

# MLH quadratic
FERTILE.fem.MLH.SQ <- lmer(FERTILE ~ lay.date.C + lay.date.C.SQ + incub.dur.C
	+ female.SH.C + female.SH.C.SQ + (1|pair.id), 
	REML = FALSE, data = my.data, na.action = na.fail)

# Add male linear
FERTILE.fem.MLH.M <- lmer(FERTILE ~ lay.date.C + lay.date.C.SQ + incub.dur.C
	+ female.SH.C + male.SH.C + (1|pair.id), 
	REML = FALSE, data = my.data, na.action = na.fail)

# Add male interaction
FERTILE.fem.MLH.Mi <- lmer(FERTILE ~ lay.date.C + lay.date.C.SQ + incub.dur.C
	+ female.SH.C + male.SH.C + female.SH.C*male.SH.C + (1|pair.id), 
	REML = FALSE, data = my.data, na.action = na.fail)

# Add pair similarity linear
FERTILE.fem.MLH.S <- lmer(FERTILE ~ lay.date.C + lay.date.C.SQ + incub.dur.C
	+ female.SH.C + pair.QGt.C + (1|pair.id), 
	REML = FALSE, data = my.data, na.action = na.fail)

# Add pair similarity interaction
FERTILE.fem.MLH.Si <- lmer(FERTILE ~ lay.date.C + lay.date.C.SQ + incub.dur.C
	+ female.SH.C + pair.QGt.C + female.SH.C*pair.QGt.C + (1|pair.id), 
	REML = FALSE, data = my.data, na.action = na.fail)


## Compare models
anova(FERTILE.null, FERTILE.fem.MLH)		# P = 0.448, df = 6,7
anova(FERTILE.fem.MLH, FERTILE.fem.SLH)		# P = 0.733, df = 7,38
anova(FERTILE.fem.MLH, FERTILE.fem.MLH.SQ)	# P = 0.510, df = 7,8
anova(FERTILE.fem.MLH, FERTILE.fem.MLH.M)		# P = 0.101, df = 7,8
anova(FERTILE.fem.MLH, FERTILE.fem.MLH.S)		# P = 0.088, df = 7,8
anova(FERTILE.fem.MLH, FERTILE.fem.MLH.Mi)	# P = 0.190, df = 7,9
anova(FERTILE.fem.MLH, FERTILE.fem.MLH.Si)	# P = 0.210, df = 7,9

#~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

#%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
#%%%%   Similarity-centred   %%%%%
#%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

# The option is there of using sim.avg instead of QGt
#  sim.avg is average of pairwise similarity

# multilocus similarity (QGt)
FERTILE.sim.MLH <- lmer(FERTILE ~ lay.date.C + lay.date.C.SQ + incub.dur.C + pair.QGt.C + (1|pair.id), 
	REML = FALSE, data = my.data, na.action = na.fail)

# Single-locus
FERTILE.sim.SLH <- lmer(FERTILE ~ lay.date.C + lay.date.C.SQ + incub.dur.C
		+ sim.loc01 + sim.loc02 + sim.loc03 + sim.loc04 + sim.loc05 + sim.loc06 + sim.loc07 + sim.loc08 + sim.loc09 + sim.loc10 
		+ sim.loc11 + sim.loc12 + sim.loc13 + sim.loc14 + sim.loc15 + sim.loc16 + sim.loc17 + sim.loc18 + sim.loc19 + sim.loc20 
		+ sim.loc21 + sim.loc22 + sim.loc23 + sim.loc24 + sim.loc25 + sim.loc26 + sim.loc27 + sim.loc28 + sim.loc29 + sim.loc30 
		+ sim.loc31 + sim.loc32	+ (1|pair.id), 
	REML = FALSE, data = my.data, na.action = na.fail)

# multilocus quadratic
FERTILE.sim.MLH.SQ <- lmer(FERTILE ~ lay.date.C + lay.date.C.SQ + incub.dur.C
	+ pair.QGt.C + pair.QGt.C.SQ + (1|pair.id), 
	REML = FALSE, data = my.data, na.action = na.fail)

# Add male linear
FERTILE.sim.MLH.M <- lmer(FERTILE ~ lay.date.C + lay.date.C.SQ + incub.dur.C
	+ pair.QGt.C + male.SH.C + (1|pair.id), 
	REML = FALSE, data = my.data, na.action = na.fail)

# Add male interaction
FERTILE.sim.MLH.Mi <- lmer(FERTILE ~ lay.date.C + lay.date.C.SQ + incub.dur.C
	+ pair.QGt.C + male.SH.C + pair.QGt.C*male.SH.C	+ (1|pair.id), 
	REML = FALSE, data = my.data, na.action = na.fail)

# Add female linear
FERTILE.sim.MLH.F <- lmer(FERTILE ~ lay.date.C + lay.date.C.SQ + incub.dur.C
	+ pair.QGt.C + female.SH.C + (1|pair.id), 
	REML = FALSE, data = my.data, na.action = na.fail)

# Add pair similarity interaction
FERTILE.sim.MLH.Fi <- lmer(FERTILE ~ lay.date.C + lay.date.C.SQ + incub.dur.C
	+ pair.QGt.C + female.SH.C + pair.QGt.C*female.SH.C + (1|pair.id), 
	REML = FALSE, data = my.data, na.action = na.fail)


## Compare models
anova(FERTILE.null, FERTILE.sim.MLH)		# P = 0.080, df = 6,7
anova(FERTILE.sim.MLH, FERTILE.sim.SLH)		# P = 0.111, df = 7,38
anova(FERTILE.sim.MLH, FERTILE.sim.MLH.SQ)	# P = 0.659, df = 7,8
anova(FERTILE.sim.MLH, FERTILE.sim.MLH.M)		# P = 0.029, df = 7,8
anova(FERTILE.sim.MLH, FERTILE.sim.MLH.F)		# P = 0.513, df = 7,8
anova(FERTILE.sim.MLH, FERTILE.sim.MLH.Mi)	# P = 0.009, df = 7,9
anova(FERTILE.sim.MLH, FERTILE.sim.MLH.Fi)	# P = 0.731, df = 7,9
#============================================================================================


#============================================================================================
#%%%%%%%%%%%%   END OF 'FERTILE' - REPEAT FOR 'HATCHED'   %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

# Null model
HATCHED.null <- lmer(HATCHED ~ lay.date.C + lay.date.C.SQ + incub.dur.C
	+ (1|pair.id), REML = FALSE, data = my.data, na.action = na.fail)


#%%%%%%%%%%%%%%%%%%%%%%%%%%%
#%%%%   Male-centred   %%%%%
#%%%%%%%%%%%%%%%%%%%%%%%%%%%

# MLH linear
HATCHED.mal.MLH <- lmer(HATCHED ~ lay.date.C + lay.date.C.SQ + incub.dur.C + male.SH.C
	+ (1|pair.id), REML = FALSE, data = my.data, na.action = na.fail)

# SLH
HATCHED.mal.SLH <- lmer(HATCHED ~ lay.date.C + lay.date.C.SQ + incub.dur.C
		+ mal.loc01.S + mal.loc02.S + mal.loc03.S + mal.loc04.S + mal.loc05.S + mal.loc06.S + mal.loc07.S + mal.loc08.S + mal.loc09.S + mal.loc10.S 
		+ mal.loc11.S + mal.loc12.S + mal.loc13.S + mal.loc14.S + mal.loc15.S + mal.loc16.S + mal.loc17.S + mal.loc18.S + mal.loc19.S + mal.loc20.S 
		+ mal.loc21.S + mal.loc22.S + mal.loc23.S + mal.loc24.S + mal.loc25.S + mal.loc26.S + mal.loc27.S + mal.loc28.S + mal.loc29.S + mal.loc30.S 
		+ mal.loc31.S + mal.loc32.S + (1|pair.id), 
	REML = FALSE, data = my.data, na.action = na.fail)

# MLH quadratic
HATCHED.mal.MLH.SQ <- lmer(HATCHED ~ lay.date.C + lay.date.C.SQ + incub.dur.C
	+ male.SH.C + male.SH.C.SQ + (1|pair.id), 
	REML = FALSE, data = my.data, na.action = na.fail)

# Add female linear
HATCHED.mal.MLH.F <- lmer(HATCHED ~ lay.date.C + lay.date.C.SQ + incub.dur.C
	+ male.SH.C + female.SH.C + (1|pair.id), 
	REML = FALSE, data = my.data, na.action = na.fail)

# Add female interaction
HATCHED.mal.MLH.Fi <- lmer(HATCHED ~ lay.date.C + lay.date.C.SQ + incub.dur.C
	+ male.SH.C + female.SH.C + male.SH.C*female.SH.C + (1|pair.id), 
	REML = FALSE, data = my.data, na.action = na.fail)

# Add pair similarity linear
HATCHED.mal.MLH.S <- lmer(HATCHED ~ lay.date.C + lay.date.C.SQ + incub.dur.C
	+ male.SH.C + pair.QGt.C + (1|pair.id), 
	REML = FALSE, data = my.data, na.action = na.fail)

# Add pair similarity interaction
HATCHED.mal.MLH.Si <- lmer(HATCHED ~ lay.date.C + lay.date.C.SQ + incub.dur.C
	+ male.SH.C + pair.QGt.C + male.SH.C*pair.QGt.C + (1|pair.id), 
	REML = FALSE, data = my.data, na.action = na.fail)


## Compare models
anova(HATCHED.null, HATCHED.mal.MLH)		# P = 0.202, df = 6,7
anova(HATCHED.mal.MLH, HATCHED.mal.SLH)		# P = 0.055, df = 7,38
anova(HATCHED.mal.MLH, HATCHED.mal.MLH.SQ)	# P = 0.248, df = 7,8
anova(HATCHED.mal.MLH, HATCHED.mal.MLH.F)		# P = 0.863, df = 7,8
anova(HATCHED.mal.MLH, HATCHED.mal.MLH.S)		# P = 0.016, df = 7,8
anova(HATCHED.mal.MLH, HATCHED.mal.MLH.Fi)	# P = 0.720, df = 7,9
anova(HATCHED.mal.MLH, HATCHED.mal.MLH.Si)	# P = 0.002, df = 7,9

## Which single loci have significant slopes? (Not really justified checking - near-sig)
summary(HATCHED.mal.SLH)
# Locus 15 (negative)
# Locus 22 (negative)
# Locus 18 is near-sig (positive)

#~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

#%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
#%%%%   Female-centred   %%%%%
#%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

# MLH linear
HATCHED.fem.MLH <- lmer(HATCHED ~ lay.date.C + lay.date.C.SQ + incub.dur.C
	+ female.SH.C + (1|pair.id), REML = FALSE, data = my.data, na.action = na.fail)

# SLH
HATCHED.fem.SLH <- lmer(HATCHED ~ lay.date.C + lay.date.C.SQ + incub.dur.C
		+ fem.loc01.S + fem.loc02.S + fem.loc03.S + fem.loc04.S + fem.loc05.S + fem.loc06.S + fem.loc07.S + fem.loc08.S + fem.loc09.S + fem.loc10.S 
		+ fem.loc11.S + fem.loc12.S + fem.loc13.S + fem.loc14.S + fem.loc15.S + fem.loc16.S + fem.loc17.S + fem.loc18.S + fem.loc19.S + fem.loc20.S 
		+ fem.loc21.S + fem.loc22.S + fem.loc23.S + fem.loc24.S + fem.loc25.S + fem.loc26.S + fem.loc27.S + fem.loc28.S + fem.loc29.S + fem.loc30.S 
		+ fem.loc31.S + fem.loc32.S + (1|pair.id), 
	REML = FALSE, data = my.data, na.action = na.fail)

# MLH quadratic
HATCHED.fem.MLH.SQ <- lmer(HATCHED ~ lay.date.C + lay.date.C.SQ + incub.dur.C
	+ female.SH.C + female.SH.C.SQ + (1|pair.id), 
	REML = FALSE, data = my.data, na.action = na.fail)

# Add male linear
HATCHED.fem.MLH.M <- lmer(HATCHED ~ lay.date.C + lay.date.C.SQ + incub.dur.C
	+ female.SH.C + male.SH.C + (1|pair.id), 
	REML = FALSE, data = my.data, na.action = na.fail)

# Add male interaction
HATCHED.fem.MLH.Mi <- lmer(HATCHED ~ lay.date.C + lay.date.C.SQ + incub.dur.C
	+ female.SH.C + male.SH.C + female.SH.C*male.SH.C + (1|pair.id), 
	REML = FALSE, data = my.data, na.action = na.fail)

# Add pair similarity linear
HATCHED.fem.MLH.S <- lmer(HATCHED ~ lay.date.C + lay.date.C.SQ + incub.dur.C
	+ female.SH.C + pair.QGt.C + (1|pair.id), 
	REML = FALSE, data = my.data, na.action = na.fail)

# Add pair similarity interaction
HATCHED.fem.MLH.Si <- lmer(HATCHED ~ lay.date.C + lay.date.C.SQ + incub.dur.C
	+ female.SH.C + pair.QGt.C + female.SH.C*pair.QGt.C + (1|pair.id), 
	REML = FALSE, data = my.data, na.action = na.fail)


## Compare models
anova(HATCHED.null, HATCHED.fem.MLH)		# P = 0.936, df = 6,7
anova(HATCHED.fem.MLH, HATCHED.fem.SLH)		# P = 0.238, df = 7,38
anova(HATCHED.fem.MLH, HATCHED.fem.MLH.SQ)	# P = 0.235, df = 7,8
anova(HATCHED.fem.MLH, HATCHED.fem.MLH.M)		# P = 0.199, df = 7,8
anova(HATCHED.fem.MLH, HATCHED.fem.MLH.S)		# P = 0.056, df = 7,8
anova(HATCHED.fem.MLH, HATCHED.fem.MLH.Mi)	# P = 0.321, df = 7,9
anova(HATCHED.fem.MLH, HATCHED.fem.MLH.Si)	# P = 0.093, df = 7,9

#~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

#%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
#%%%%   Similarity-centred   %%%%%
#%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

# Multilocus similarity (QGt)
HATCHED.sim.MLH <- lmer(HATCHED ~ lay.date.C + lay.date.C.SQ + incub.dur.C + pair.QGt.C + (1|pair.id), 
	REML = FALSE, data = my.data, na.action = na.fail)

# Single-locus
HATCHED.sim.SLH <- lmer(HATCHED ~ lay.date.C + lay.date.C.SQ + incub.dur.C
		+ sim.loc01 + sim.loc02 + sim.loc03 + sim.loc04 + sim.loc05 + sim.loc06 + sim.loc07 + sim.loc08 + sim.loc09 + sim.loc10 
		+ sim.loc11 + sim.loc12 + sim.loc13 + sim.loc14 + sim.loc15 + sim.loc16 + sim.loc17 + sim.loc18 + sim.loc19 + sim.loc20 
		+ sim.loc21 + sim.loc22 + sim.loc23 + sim.loc24 + sim.loc25 + sim.loc26 + sim.loc27 + sim.loc28 + sim.loc29 + sim.loc30 
		+ sim.loc31 + sim.loc32 + (1|pair.id), 
	REML = FALSE, data = my.data, na.action = na.fail)

# multilocus quadratic
HATCHED.sim.MLH.SQ <- lmer(HATCHED ~ lay.date.C + lay.date.C.SQ + incub.dur.C
	+ pair.QGt.C + pair.QGt.C.SQ + (1|pair.id), 
	REML = FALSE, data = my.data, na.action = na.fail)

# Add male linear
HATCHED.sim.MLH.M <- lmer(HATCHED ~ lay.date.C + lay.date.C.SQ + incub.dur.C
	+ pair.QGt.C + male.SH.C + (1|pair.id), 
	REML = FALSE, data = my.data, na.action = na.fail)

# Add male interaction
HATCHED.sim.MLH.Mi <- lmer(HATCHED ~ lay.date.C + lay.date.C.SQ + incub.dur.C
	+ pair.QGt.C + male.SH.C + pair.QGt.C*male.SH.C + (1|pair.id), 
	REML = FALSE, data = my.data, na.action = na.fail)

# Add female linear
HATCHED.sim.MLH.F <- lmer(HATCHED ~ lay.date.C + lay.date.C.SQ + incub.dur.C
	+ pair.QGt.C + female.SH.C + (1|pair.id), 
	REML = FALSE, data = my.data, na.action = na.fail)

# Add pair similarity interaction
HATCHED.sim.MLH.Fi <- lmer(HATCHED ~ lay.date.C + lay.date.C.SQ + incub.dur.C
	+ pair.QGt.C + female.SH.C + pair.QGt.C*female.SH.C + (1|pair.id), 
	REML = FALSE, data = my.data, na.action = na.fail)


## Compare models
anova(HATCHED.null, HATCHED.sim.MLH)		# P = 0.056, df = 6,7*
anova(HATCHED.sim.MLH, HATCHED.sim.SLH)		# P < 0.001, df = 7,38*
anova(HATCHED.sim.MLH, HATCHED.sim.MLH.SQ)	# P = 0.210, df = 7,8
anova(HATCHED.sim.MLH, HATCHED.sim.MLH.M)		# P = 0.052, df = 7,8*
anova(HATCHED.sim.MLH, HATCHED.sim.MLH.F)		# P = 0.975, df = 7,8
anova(HATCHED.sim.MLH, HATCHED.sim.MLH.Mi)	# P = 0.006, df = 7,9*
anova(HATCHED.sim.MLH, HATCHED.sim.MLH.Fi)	# P = 0.578, df = 7,9


## repeat models of interest with 'sim.avg' as similarity predictor

HATCHED.simAV.MLH <- lmer(HATCHED ~ lay.date.C + lay.date.C.SQ + incub.dur.C + sim.avg.C + (1|pair.id), 
	REML = FALSE, data = my.data, na.action = na.fail)

HATCHED.simAV.MLH.M <- lmer(HATCHED ~ lay.date.C + lay.date.C.SQ + incub.dur.C
	+ sim.avg.C + male.SH.C	+ (1|pair.id), 
	REML = FALSE, data = my.data, na.action = na.fail)

HATCHED.simAV.MLH.Mi <- lmer(HATCHED ~ lay.date.C + lay.date.C.SQ + incub.dur.C
	+ sim.avg.C + male.SH.C + sim.avg.C*male.SH.C + (1|pair.id), 
	REML = FALSE, data = my.data, na.action = na.fail)

anova(HATCHED.null, HATCHED.simAV.MLH)		# P = 0.078, df = 6,7*
anova(HATCHED.simAV.MLH, HATCHED.sim.SLH)		# P < 0.001, df = 7,38*
anova(HATCHED.simAV.MLH, HATCHED.simAV.MLH.M)	# P = 0.020, df = 7,8*
anova(HATCHED.simAV.MLH, HATCHED.simAV.MLH.Mi)	# P = 0.006, df = 7,9*

## Which single loci have significant slopes?
summary(HATCHED.sim.SLH)
# Loci 11, 17, 21 & 22 (negative), and 13 (positive)
# Two other loci are near-sig: 19 & 20
#============================================================================================


#============================================================================================
#@@@@@@@@@@@@   END OF 'HATCHED' - REPEAT FOR 'TO.SEA'   @@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@

# remove the one nest with no offspring to sea - nest flooded on hatching, so all dead in nest
data.to.sea <- subset(my.data, TO.SEA != "NA"); data.to.sea$TO.SEA 

# Null
TO.SEA.null <- lmer(TO.SEA ~ lay.date.C + lay.date.C.SQ + incub.dur.C + (1|pair.id), 
	REML = FALSE, data = data.to.sea, na.action = na.fail)


#%%%%%%%%%%%%%%%%%%%%%%%%%%%
#%%%%   Male-centred   %%%%%
#%%%%%%%%%%%%%%%%%%%%%%%%%%%

# MLH linear
TO.SEA.mal.MLH <- lmer(TO.SEA ~ lay.date.C + lay.date.C.SQ + incub.dur.C + male.SH.C + (1|pair.id), 
	REML = FALSE, data = data.to.sea, na.action = na.fail)

# SLH
TO.SEA.mal.SLH <- lmer(TO.SEA ~ lay.date.C + lay.date.C.SQ + incub.dur.C
		+ mal.loc01.S + mal.loc02.S + mal.loc03.S + mal.loc04.S + mal.loc05.S + mal.loc06.S + mal.loc07.S + mal.loc08.S + mal.loc09.S + mal.loc10.S 
		+ mal.loc11.S + mal.loc12.S + mal.loc13.S + mal.loc14.S + mal.loc15.S + mal.loc16.S + mal.loc17.S + mal.loc18.S + mal.loc19.S + mal.loc20.S 
		+ mal.loc21.S + mal.loc22.S + mal.loc23.S + mal.loc24.S + mal.loc25.S + mal.loc26.S + mal.loc27.S + mal.loc28.S + mal.loc29.S + mal.loc30.S 
		+ mal.loc31.S + mal.loc32.S + (1|pair.id), 
	REML = FALSE, data = data.to.sea, na.action = na.fail)

# MLH quadratic
TO.SEA.mal.MLH.SQ <- lmer(TO.SEA ~ lay.date.C + lay.date.C.SQ + incub.dur.C
	+ male.SH.C + male.SH.C.SQ + (1|pair.id), 
	REML = FALSE, data = data.to.sea, na.action = na.fail)

# Add female linear
TO.SEA.mal.MLH.F <- lmer(TO.SEA ~ lay.date.C + lay.date.C.SQ + incub.dur.C
	+ male.SH.C + female.SH.C + (1|pair.id), 
	REML = FALSE, data = data.to.sea, na.action = na.fail)

# Add female interaction
TO.SEA.mal.MLH.Fi <- lmer(TO.SEA ~ lay.date.C + lay.date.C.SQ + incub.dur.C
	+ male.SH.C + female.SH.C + male.SH.C*female.SH.C + (1|pair.id), 
	REML = FALSE, data = data.to.sea, na.action = na.fail)

# Add pair similarity linear
TO.SEA.mal.MLH.S <- lmer(TO.SEA ~ lay.date.C + lay.date.C.SQ + incub.dur.C
	+ male.SH.C + pair.QGt.C + (1|pair.id), 
	REML = FALSE, data = data.to.sea, na.action = na.fail)

# Add pair similarity interaction
TO.SEA.mal.MLH.Si <- lmer(TO.SEA ~ lay.date.C + lay.date.C.SQ + incub.dur.C
	+ male.SH.C + pair.QGt.C + male.SH.C*pair.QGt.C	+ (1|pair.id), 
	REML = FALSE, data = data.to.sea, na.action = na.fail)


## Compare models
anova(TO.SEA.null, TO.SEA.mal.MLH)		# P = 0.166, df = 6,7
anova(TO.SEA.mal.MLH, TO.SEA.mal.SLH)	# P = 0.009, df = 7,38
anova(TO.SEA.mal.MLH, TO.SEA.mal.MLH.SQ)	# P = 0.324, df = 7,8
anova(TO.SEA.mal.MLH, TO.SEA.mal.MLH.F)	# P = 0.950, df = 7,8
anova(TO.SEA.mal.MLH, TO.SEA.mal.MLH.S)	# P = 0.013, df = 7,8
anova(TO.SEA.mal.MLH, TO.SEA.mal.MLH.Fi)	# P = 0.678, df = 7,9
anova(TO.SEA.mal.MLH, TO.SEA.mal.MLH.Si)	# P = 0.002, df = 7,9

## Which single loci have significant slopes?
summary(TO.SEA.mal.SLH)
# Locus 06 (positive)
# Locus 15 (negative)
# Locus 18 (positive)
# Locus 20 (negative)
# Locus 22 (negative)
# Locus 26 (negative)
# 29 is near-sig

#~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

#%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
#%%%%   Female-centred   %%%%%
#%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

# MLH linear
TO.SEA.fem.MLH <- lmer(TO.SEA ~ lay.date.C + lay.date.C.SQ + incub.dur.C + female.SH.C + (1|pair.id), 
	REML = FALSE, data = data.to.sea, na.action = na.fail)

# SLH
TO.SEA.fem.SLH <- lmer(TO.SEA ~ lay.date.C + lay.date.C.SQ + incub.dur.C
		+ fem.loc01.S + fem.loc02.S + fem.loc03.S + fem.loc04.S + fem.loc05.S + fem.loc06.S + fem.loc07.S + fem.loc08.S + fem.loc09.S + fem.loc10.S 
		+ fem.loc11.S + fem.loc12.S + fem.loc13.S + fem.loc14.S + fem.loc15.S + fem.loc16.S + fem.loc17.S + fem.loc18.S + fem.loc19.S + fem.loc20.S 
		+ fem.loc21.S + fem.loc22.S + fem.loc23.S + fem.loc24.S + fem.loc25.S + fem.loc26.S + fem.loc27.S + fem.loc28.S + fem.loc29.S + fem.loc30.S 
		+ fem.loc31.S + fem.loc32.S + (1|pair.id), 
	REML = FALSE, data = data.to.sea, na.action = na.fail)

# MLH quadratic
TO.SEA.fem.MLH.SQ <- lmer(TO.SEA ~ lay.date.C + lay.date.C.SQ + incub.dur.C
	+ female.SH.C + female.SH.C.SQ + (1|pair.id), 
	REML = FALSE, data = data.to.sea, na.action = na.fail)

# Add male linear
TO.SEA.fem.MLH.M <- lmer(TO.SEA ~ lay.date.C + lay.date.C.SQ + incub.dur.C
	+ female.SH.C + male.SH.C + (1|pair.id), 
	REML = FALSE, data = data.to.sea, na.action = na.fail)

# Add male interaction
TO.SEA.fem.MLH.Mi <- lmer(TO.SEA ~ lay.date.C + lay.date.C.SQ + incub.dur.C
	+ female.SH.C + male.SH.C + female.SH.C*male.SH.C + (1|pair.id), 
	REML = FALSE, data = data.to.sea, na.action = na.fail)

# Add pair similarity linear
TO.SEA.fem.MLH.S <- lmer(TO.SEA ~ lay.date.C + lay.date.C.SQ + incub.dur.C
	+ female.SH.C + pair.QGt.C + (1|pair.id), 
	REML = FALSE, data = data.to.sea, na.action = na.fail)

# Add pair similarity interaction
TO.SEA.fem.MLH.Si <- lmer(TO.SEA ~ lay.date.C + lay.date.C.SQ + incub.dur.C
	+ female.SH.C + pair.QGt.C + female.SH.C*pair.QGt.C + (1|pair.id), 
	REML = FALSE, data = data.to.sea, na.action = na.fail)


## Compare models
anova(TO.SEA.null, TO.SEA.fem.MLH)		# P = 0.964, df = 6,7
anova(TO.SEA.fem.MLH, TO.SEA.fem.SLH)	# P = 0.216, df = 7,38
anova(TO.SEA.fem.MLH, TO.SEA.fem.MLH.SQ)	# P = 0.276, df = 7,8
anova(TO.SEA.fem.MLH, TO.SEA.fem.MLH.M)	# P = 0.166, df = 7,8
anova(TO.SEA.fem.MLH, TO.SEA.fem.MLH.S)	# P = 0.055, df = 7,8
anova(TO.SEA.fem.MLH, TO.SEA.fem.MLH.Mi)	# P = 0.260, df = 7,9
anova(TO.SEA.fem.MLH, TO.SEA.fem.MLH.Si)	# P = 0.159, df = 7,9

#~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

#%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
#%%%%   Similarity-centred   %%%%%
#%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

# multilocus similarity (QGt)
TO.SEA.sim.MLH <- lmer(TO.SEA ~ lay.date.C + lay.date.C.SQ + incub.dur.C + pair.QGt.C + (1|pair.id), 
	REML = FALSE, data = data.to.sea, na.action = na.fail)

# Single-locus
TO.SEA.sim.SLH <- lmer(TO.SEA ~ lay.date.C + lay.date.C.SQ + incub.dur.C
		+ sim.loc01 + sim.loc02 + sim.loc03 + sim.loc04 + sim.loc05 + sim.loc06 + sim.loc07 + sim.loc08 + sim.loc09 + sim.loc10 
		+ sim.loc11 + sim.loc12 + sim.loc13 + sim.loc14 + sim.loc15 + sim.loc16 + sim.loc17 + sim.loc18 + sim.loc19 + sim.loc20 
		+ sim.loc21 + sim.loc22 + sim.loc23 + sim.loc24 + sim.loc25 + sim.loc26 + sim.loc27 + sim.loc28 + sim.loc29 + sim.loc30 
		+ sim.loc31 + sim.loc32 + (1|pair.id), 
	REML = FALSE, data = data.to.sea, na.action = na.fail)

# Multilocus quadratic
TO.SEA.sim.MLH.SQ <- lmer(TO.SEA ~ lay.date.C + lay.date.C.SQ + incub.dur.C
	+ pair.QGt.C + pair.QGt.C.SQ + (1|pair.id), 
	REML = FALSE, data = data.to.sea, na.action = na.fail)

# Add male linear
TO.SEA.sim.MLH.M <- lmer(TO.SEA ~ lay.date.C + lay.date.C.SQ + incub.dur.C
	+ pair.QGt.C + male.SH.C + (1|pair.id), 
	REML = FALSE, data = data.to.sea, na.action = na.fail)

# Add male interaction
TO.SEA.sim.MLH.Mi <- lmer(TO.SEA ~ lay.date.C + lay.date.C.SQ + incub.dur.C
	+ pair.QGt.C + male.SH.C + pair.QGt.C*male.SH.C + (1|pair.id), 
	REML = FALSE, data = data.to.sea, na.action = na.fail)

# Add female linear
TO.SEA.sim.MLH.F <- lmer(TO.SEA ~ lay.date.C + lay.date.C.SQ + incub.dur.C
	+ pair.QGt.C + female.SH.C + (1|pair.id), 
	REML = FALSE, data = data.to.sea, na.action = na.fail)

# Add pair similarity interaction
TO.SEA.sim.MLH.Fi <- lmer(TO.SEA ~ lay.date.C + lay.date.C.SQ + incub.dur.C
	+ pair.QGt.C + female.SH.C + pair.QGt.C*female.SH.C + (1|pair.id), 
	REML = FALSE, data = data.to.sea, na.action = na.fail)


## Compare models
anova(TO.SEA.null, TO.SEA.sim.MLH)		# P = 0.057, df = 6,7*
anova(TO.SEA.sim.MLH, TO.SEA.sim.SLH)	# P = 0.001, df = 7,38*
anova(TO.SEA.sim.MLH, TO.SEA.sim.MLH.SQ)	# P = 0.137, df = 7,8
anova(TO.SEA.sim.MLH, TO.SEA.sim.MLH.M)	# P = 0.035, df = 7,8*
anova(TO.SEA.sim.MLH, TO.SEA.sim.MLH.F)	# P = 0.837, df = 7,8
anova(TO.SEA.sim.MLH, TO.SEA.sim.MLH.Mi)	# P = 0.004, df = 7,9*
anova(TO.SEA.sim.MLH, TO.SEA.sim.MLH.Fi)	# P = 0.972, df = 7,9

summary(TO.SEA.sim.MLH.Mi)
plot(sim.avg.C~pair.QGt.C, data = data.to.sea)


## repeat models of interest with 'sim.avg' as similarity predictor

TO.SEA.simAV.MLH <- lmer(TO.SEA ~ lay.date.C + lay.date.C.SQ + incub.dur.C + sim.avg.C + (1|pair.id), 
	REML = FALSE, data = data.to.sea, na.action = na.fail)

TO.SEA.simAV.MLH.M <- lmer(TO.SEA ~ lay.date.C + lay.date.C.SQ + incub.dur.C
	+ sim.avg.C + male.SH.C + (1|pair.id), 
	REML = FALSE, data = data.to.sea, na.action = na.fail)

TO.SEA.simAV.MLH.Mi <- lmer(TO.SEA ~ lay.date.C + lay.date.C.SQ + incub.dur.C
	+ sim.avg.C + male.SH.C + sim.avg.C*male.SH.C + (1|pair.id), 
	REML = FALSE, data = data.to.sea, na.action = na.fail)


anova(TO.SEA.null, TO.SEA.simAV.MLH)		# P = 0.076, df = 6,7*
anova(TO.SEA.simAV.MLH, TO.SEA.sim.SLH)		# P = 0.001, df = 7,38*
anova(TO.SEA.simAV.MLH, TO.SEA.simAV.MLH.M)	# P = 0.012, df = 7,8*
anova(TO.SEA.simAV.MLH, TO.SEA.simAV.MLH.Mi)	# P = 0.004, df = 7,9*

## Which single loci have significant slopes?
summary(TO.SEA.sim.SLH)
# Locus 11 & 21 (negative), & 30 (positive)
# Four others are near-sig
#============================================================================================
