# Heterozygosity-fitness correlations against success of eggs
# MAIN ANALYSES WITH MALES AND RELATEDNESS
#  - tests TO.SEA as response, with SH as predictor
# Only MLH tests present here - SLH tests are in another script
# Tests of female heterozygosity against eggs laid are in another script
# Tests of MP nests against SP nests are in another script
# A wider test of female MLH using all typed females is in another script


# Revised 2017-08-01 for Dryad
#  - tidied, streamlined, and better annotated

#--------------------------------------------------------------------------------------------
# Clear R
rm(list = ls())

# Load necessary packages
library(MASS)
library(lme4)
#library(lmerTest)
library(moments)
library(MuMIn)
#--------------------------------------------------------------------------------------------


#--------------------------------------------------------------------------------------------
####  BRING IN DATA  ########

# Set WD
setwd("FILEPATH")

# Read datafile
data.FULL <- read.csv("00_HFC_extendedData.csv")
#--------------------------------------------------------------------------------------------


#--------------------------------------------------------------------------------------------
## Code for Nakagawa Rsq for LMM
## http://jslefche.wordpress.com/2013/03/13/r2-for-linear-mixed-effects-models/
## Updated by us, as original was written for lme4 in R v2

rsquared.lme=function(modlist) {
  #Iterate over each model in the list
  do.call(rbind,lapply(modlist,function(i) {
    #For models fit using lm
    if(class(i)=="lm") {
      Rsquared.mat=data.frame(Class=class(i),Marginal=summary(i)$r.squared,
                              Conditional=NA,AIC=AIC(i)) } 
    #For models fit using lme4
    else if(class(i)=="mer" | class(i)=="merMod" | class(i)=="merLmerTest") {
      #Get variance of fixed effects by multiplying coefficients by design matrix
      VarF=var(as.vector(fixef(i) %*% t(i@X))) 
      #Get variance of random effects by extracting variance components
      VarRand=colSums(do.call(rbind,lapply(VarCorr(i),function(j) j[1])))
      #Get residual variance
      VarResid=attr(VarCorr(i),"sc")^2
      #Calculate marginal R-squared (fixed effects/total variance)
      Rm=VarF/(VarF+VarRand+VarResid)
      #Calculate conditional R-squared (fixed effects+random effects/total variance)
      Rc=(VarF+VarRand)/(VarF+VarRand+VarResid)
      #Bind R^2s into a matrix and return with AIC values
      Rsquared.mat=data.frame(Class=class(i),Marginal=Rm,Conditional=Rc,
                              AIC=AIC(update(i,REML=F))) } 
    #For models fit using NEWER VERSION of lme4 WITH lmerTest
    else if(class(i)=="lmerMod" | class(i)=="merModLmerTest") {
      #Get variance of fixed effects by multiplying coefficients by design matrix
      VarF=var(as.vector(fixef(i) %*% t(i@pp$X))) 
      #Get variance of random effects by extracting variance components
      VarRand=colSums(do.call(rbind,lapply(VarCorr(i),function(j) j[1])))
      #Get residual variance
      VarResid=attr(VarCorr(i),"sc")^2
      #Calculate marginal R-squared (fixed effects/total variance)
      Rm=VarF/(VarF+VarRand+VarResid)
      #Calculate conditional R-squared (fixed effects+random effects/total variance)
      Rc=(VarF+VarRand)/(VarF+VarRand+VarResid)
      #Bind R^2s into a matrix and return with AIC values
      Rsquared.mat=data.frame(Class=class(i),Marginal=Rm,Conditional=Rc,
                              AIC=AIC(update(i,REML=F))) } 
    #For model fit using nlme  
    else if(class(i)=="lme") {
      #Get design matrix of fixed effects from model
      Fmat=model.matrix(eval(i$call$fixed)[-2],i$data)
      #Get variance of fixed effects by multiplying coefficients by design matrix
      VarF=var(as.vector(fixef(i) %*% t(Fmat)))
      #Get variance of random effects by extracting variance components
      VarRand=sum(suppressWarnings(as.numeric(VarCorr(i)[rownames(VarCorr(i))!=
                                                           "Residual",1])),na.rm=T)
      #Get residual variance
      VarResid=as.numeric(VarCorr(i)[rownames(VarCorr(i))=="Residual",1])
      #Calculate marginal R-squared (fixed effects/total variance)
      Rm=VarF/(VarF+VarRand+VarResid)
      #Calculate conditional R-squared (fixed effects+random effects/total variance)
      Rc=(VarF+VarRand)/(VarF+VarRand+VarResid)
      #Bind R^2s into a matrix and return with AIC values
      Rsquared.mat=data.frame(Class=class(i),Marginal=Rm,Conditional=Rc,
                              AIC=AIC(update(i,method="ML")))
    } else { print("Function requires models of class lm, lme, mer, or merMod") 
    } } ) ) }
#  rsquared.lme(list( ENTER MODEL NAMES HERE ))
#--------------------------------------------------------------------------------------------


#--------------------------------------------------------------------------------------------
##  Collinearity diagnostics

vif.mer <- function (fit) {
  ## adapted from rms::vif
  
  v <- vcov(fit)
  nam <- names(fixef(fit))
  
  ## exclude intercepts
  ns <- sum(1 * (nam == "Intercept" | nam == "(Intercept)"))
  if (ns > 0) {
    v <- v[-(1:ns), -(1:ns), drop = FALSE]
    nam <- nam[-(1:ns)]
  }
  
  d <- diag(v)^0.5
  v <- diag(solve(v/(d %o% d)))
  names(v) <- nam
  v
}

kappa.mer <- function (fit,
                       scale = TRUE, center = FALSE,
                       add.intercept = TRUE,
                       exact = FALSE) {
  X <- fit@pp$X
  nam <- names(fixef(fit))
  
  ## exclude intercepts
  nrp <- sum(1 * (nam == "(Intercept)"))
  if (nrp > 0) {
    X <- X[, -(1:nrp), drop = FALSE]
    nam <- nam[-(1:nrp)]
  }
  
  if (add.intercept) {
    X <- cbind(rep(1), scale(X, scale = scale, center = center))
    kappa(X, exact = exact)
  } else {
    kappa(scale(X, scale = scale, center = scale), exact = exact)
  }
}
#--------------------------------------------------------------------------------------------


#--------------------------------------------------------------------------------------------
####  EXAMINE/REFINE DATA  ########
# Examine
str(data.FULL, list.len = 220)
names(data.FULL)
nrow(data.FULL)

# Columns for focal analyses
colList <- c("het.v.success", "TO.SEA", "year", "pair.id", "female.id", "male.id", "male.offspringtyped", 
	"female.SH", "male.SH", "pair.QGt", "sim.avg", "lay.date", "incub.dur.1", "eggs.laid", "CCL")

# Get focal subset for these analyses
my.data <- data.FULL[data.FULL$het.v.success == "Y", colList]
str(my.data, list.len = 220)
nrow(my.data)

# Redefine numerical variables that need to be factors
my.data$year <- factor(my.data$year)
my.data$pair.id <- factor(my.data$pair.id)
my.data$female.id <- factor(my.data$female.id)
my.data$male.id <- factor(my.data$male.id)

# check structure again
str(my.data, list.len = 220)
#--------------------------------------------------------------------------------------------


#--------------------------------------------------------------------------------------------
# CREATE NEW VARIABLES
#  - mean-centering the genetic predictors
#  - make quadratic variables

# Mean-centre variables
# Date & incubation duration - though incub isn't used
my.data$lay.date.C <- scale(my.data$lay.date, center = TRUE, scale = FALSE)
my.data$incub.dur.C <- scale(my.data$incub.dur.1, center = TRUE, scale = FALSE)

# Genetics
my.data$female.SH.C <- scale(my.data$female.SH, center = TRUE, scale = FALSE)
my.data$male.SH.C <- scale(my.data$male.SH, center = TRUE, scale = FALSE)
my.data$pair.QGt.C <- scale(my.data$pair.QGt, center = TRUE, scale = FALSE)
my.data$sim.avg.C <- scale(my.data$sim.avg, center = TRUE, scale = FALSE)

# Make quadratic variables
my.data$lay.date.C.SQ <- my.data$lay.date.C^2
my.data$incub.dur.C.SQ <- my.data$incub.dur.C^2
#
my.data$female.SH.C.SQ <- my.data$female.SH.C^2
my.data$male.SH.C.SQ <- my.data$male.SH.C^2
my.data$pair.QGt.C.SQ <- my.data$pair.QGt.C^2
my.data$sim.avg.C.SQ <- my.data$sim.avg.C^2

names(my.data)
str(my.data)
#--------------------------------------------------------------------------------------------

#@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@
#@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@
#@@@@@@@@@@@@  ~~~~~~~~~~~~~~~~~  @@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@
#@@@@@@@@@@@@    MAIN ANALYSES    @@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@
#@@@@@@@@@@@@  ~~~~~~~~~~~~~~~~~  @@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@
#@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@
#@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@

#--------------------------------------------------------------------------------------------
# Remove the one nest with no offspring to sea - nest flooded on hatching, so all dead in nest
data.to.sea <- my.data[!is.na(my.data$TO.SEA),]
data.to.sea$TO.SEA 
#--------------------------------------------------------------------------------------------


#--------------------------------------------------------------------------------------------
# Main analyses

# Functional null model
TO.SEA.null <- lmer(TO.SEA ~ lay.date.C + lay.date.C.SQ + incub.dur.C + (1|pair.id),
	data = data.to.sea, REML = FALSE, na.action = na.fail)

summary(TO.SEA.null)

# Maximum model for dredge
TO.SEA.MLH.base <- lmer(TO.SEA ~ lay.date.C + lay.date.C.SQ + incub.dur.C +
		male.SH.C + female.SH.C + pair.QGt.C + 
		male.SH.C.SQ + female.SH.C.SQ + pair.QGt.C.SQ + 
		male.SH.C*female.SH.C + male.SH.C*pair.QGt.C + female.SH.C*pair.QGt.C
		+ (1|pair.id),
	data = data.to.sea, REML = FALSE, na.action = na.fail)

# Select subset of models to run
# allow: A) null; B) all combinations of linear main effects of the three predictors;
#     c) all genetic quadratic terms, but with their own linear term ONLY;
#	d) all pairwise interactions, with both main effects
TO.SEA.MLH.dredge <- dredge(TO.SEA.MLH.base, m.lim=c(3,6),
	fixed = c("lay.date.C", "lay.date.C.SQ", "incub.dur.C"), 
	subset = dc(male.SH.C, male.SH.C.SQ) && dc(female.SH.C, female.SH.C.SQ) && dc(pair.QGt.C, pair.QGt.C.SQ) 
			&& !(male.SH.C && female.SH.C.SQ) && !(male.SH.C && pair.QGt.C.SQ)
			&& !(female.SH.C && male.SH.C.SQ) && !(female.SH.C && pair.QGt.C.SQ)
			&& !(pair.QGt.C && female.SH.C.SQ) && !(pair.QGt.C && male.SH.C.SQ),
				extra = c("P.v.null" = function(x) {
				test.val <- anova(TO.SEA.null,x)
				test.val$Pr[[2]]})	)

# Convert dredge object to dataframe
TO.SEA.M <- data.frame(TO.SEA.MLH.dredge)
nrow(TO.SEA.M)

TO.SEA.M 
# There is an outright winner


# Get summaries of models that are significantly better than the null (2 AICc units better)
# BEST: interaction and male main effect are significant
# SECOND: male main and QGt main are significant

BEST.1st <- lmer(TO.SEA ~ lay.date.C + lay.date.C.SQ + incub.dur.C 
	+ male.SH.C + pair.QGt.C + male.SH.C*pair.QGt.C 
	+ (1|pair.id), data = data.to.sea, REML = FALSE, na.action = na.fail)

BEST.2nd <- lmer(TO.SEA ~ lay.date.C + lay.date.C.SQ + incub.dur.C 
	+ male.SH.C + pair.QGt.C + (1|pair.id), 
	data = data.to.sea, REML = FALSE, na.action = na.fail)

# Get summaries of the models; include null
TO.SEA.bestMods <- list(TO.SEA.null, BEST.1st, BEST.2nd)
lapply(TO.SEA.bestMods, function(x) summary(x))


# Get Nakagawa R2 
rsquared.lme(TO.SEA.bestMods)


# Collinearity diagnostics
lapply(TO.SEA.bestMods, function(x) vif.mer(x))
# all between 1.06 and 1.16 over both models

lapply(TO.SEA.bestMods, function(x) kappa.mer(x))
# 2.55 and 2.32


# Normality of residuals
lapply(TO.SEA.bestMods, function(x){
	RESIDS <- residuals(x)
	return(c(shapiro.test(RESIDS)$p.value, skewness(RESIDS), kurtosis(RESIDS))) })

# Second best model is marginally sig for Shapiro - slight skew and flattening
hist(residuals(TO.SEA.bestMods[[1]]))
hist(residuals(TO.SEA.bestMods[[2]]))


# Table of lmer R2
mod.names <- c("null", "mal", "fem", "sim", "M+F", "M+S", "F+S", "M+F+S", "Msq", "Fsq", "Ssq", "MxF", "MxS", "FxS")

TO.SEA.R2Tab.00 <- lmer(TO.SEA ~ lay.date.C + lay.date.C.SQ + incub.dur.C + (1|pair.id), data = data.to.sea, REML = FALSE, na.action = na.fail)
TO.SEA.R2Tab.01 <- lmer(TO.SEA ~ lay.date.C + lay.date.C.SQ + incub.dur.C + male.SH.C + (1|pair.id), data = data.to.sea, REML = FALSE, na.action = na.fail)
TO.SEA.R2Tab.02 <- lmer(TO.SEA ~ lay.date.C + lay.date.C.SQ + incub.dur.C + female.SH.C + (1|pair.id), data = data.to.sea, REML = FALSE, na.action = na.fail)
TO.SEA.R2Tab.03 <- lmer(TO.SEA ~ lay.date.C + lay.date.C.SQ + incub.dur.C + pair.QGt.C + (1|pair.id), data = data.to.sea, REML = FALSE, na.action = na.fail)

TO.SEA.R2Tab.04 <- lmer(TO.SEA ~ lay.date.C + lay.date.C.SQ + incub.dur.C + male.SH.C + female.SH.C + (1|pair.id), data = data.to.sea, REML = FALSE, na.action = na.fail)
TO.SEA.R2Tab.05 <- lmer(TO.SEA ~ lay.date.C + lay.date.C.SQ + incub.dur.C + male.SH.C + pair.QGt.C + (1|pair.id), data = data.to.sea, REML = FALSE, na.action = na.fail)
TO.SEA.R2Tab.06 <- lmer(TO.SEA ~ lay.date.C + lay.date.C.SQ + incub.dur.C + female.SH.C + pair.QGt.C + (1|pair.id), data = data.to.sea, REML = FALSE, na.action = na.fail)
TO.SEA.R2Tab.07 <- lmer(TO.SEA ~ lay.date.C + lay.date.C.SQ + incub.dur.C + male.SH.C + female.SH.C + pair.QGt.C + (1|pair.id), data = data.to.sea, REML = FALSE, na.action = na.fail)

TO.SEA.R2Tab.08 <- lmer(TO.SEA ~ lay.date.C + lay.date.C.SQ + incub.dur.C + male.SH.C + male.SH.C.SQ + (1|pair.id), data = data.to.sea, REML = FALSE, na.action = na.fail)
TO.SEA.R2Tab.09 <- lmer(TO.SEA ~ lay.date.C + lay.date.C.SQ + incub.dur.C + female.SH.C + female.SH.C.SQ + (1|pair.id), data = data.to.sea, REML = FALSE, na.action = na.fail)
TO.SEA.R2Tab.10 <- lmer(TO.SEA ~ lay.date.C + lay.date.C.SQ + incub.dur.C + pair.QGt.C + pair.QGt.C.SQ + (1|pair.id), data = data.to.sea, REML = FALSE, na.action = na.fail)

TO.SEA.R2Tab.11 <- lmer(TO.SEA ~ lay.date.C + lay.date.C.SQ + incub.dur.C + male.SH.C + female.SH.C + male.SH.C*female.SH.C + (1|pair.id), data = data.to.sea, REML = FALSE, na.action = na.fail)
TO.SEA.R2Tab.12 <- lmer(TO.SEA ~ lay.date.C + lay.date.C.SQ + incub.dur.C + male.SH.C + pair.QGt.C + male.SH.C*pair.QGt.C + (1|pair.id), data = data.to.sea, REML = FALSE, na.action = na.fail)
TO.SEA.R2Tab.13 <- lmer(TO.SEA ~ lay.date.C + lay.date.C.SQ + incub.dur.C + female.SH.C + pair.QGt.C + female.SH.C*pair.QGt.C + (1|pair.id), data = data.to.sea, REML = FALSE, na.action = na.fail)

TO.SEA.Rsq.table <- rsquared.lme(list(TO.SEA.R2Tab.00, TO.SEA.R2Tab.01, TO.SEA.R2Tab.02, TO.SEA.R2Tab.03,
	TO.SEA.R2Tab.04, TO.SEA.R2Tab.05, TO.SEA.R2Tab.06, TO.SEA.R2Tab.07, TO.SEA.R2Tab.08, TO.SEA.R2Tab.09,
	TO.SEA.R2Tab.10, TO.SEA.R2Tab.11, TO.SEA.R2Tab.12, TO.SEA.R2Tab.13))

TO.SEA.Rsq.table$mod.name <- mod.names
TO.SEA.Rsq.table$Marg.diff <- round(TO.SEA.Rsq.table$Marginal - TO.SEA.Rsq.table$Marginal[1],3)
TO.SEA.Rsq.table$Cond.diff <- round(TO.SEA.Rsq.table$Conditional - TO.SEA.Rsq.table$Conditional[1],3)
TO.SEA.Rsq.table

#--------------------------------------------------------------------------------------------
