#############################################################################################
#############################################################################################
## Re-run the main analyses, deleting one family at a time
##  - how well does the result hold up?

# Revised 2017-08-01 for Dryad
#  - tidied, streamlined, and better annotated

#--------------------------------------------------------------------------------------------
# Clear R
rm(list = ls())

# Load necessary packages
library(lme4)
library(MuMIn)
#--------------------------------------------------------------------------------------------


#--------------------------------------------------------------------------------------------
####  BRING IN DATA  ########

# Set WD
setwd("FILEPATH")

# Read datafile
real.data <- read.csv("00_HFC_coreData_focalFamilies.csv")
names(real.data)
#--------------------------------------------------------------------------------------------


#--------------------------------------------------------------------------------------------
## Code for Nakagawa Rsq for LMM
## http://jslefche.wordpress.com/2013/03/13/r2-for-linear-mixed-effects-models/
## Updated by us, as original was written for lme4 in R v2

rsquared.lme=function(modlist) {
  #Iterate over each model in the list
  do.call(rbind,lapply(modlist,function(i) {
    #For models fit using lm
    if(class(i)=="lm") {
      Rsquared.mat=data.frame(Class=class(i),Marginal=summary(i)$r.squared,
                              Conditional=NA,AIC=AIC(i)) } 
    #For models fit using lme4
    else if(class(i)=="mer" | class(i)=="merMod" | class(i)=="merLmerTest") {
      #Get variance of fixed effects by multiplying coefficients by design matrix
      VarF=var(as.vector(fixef(i) %*% t(i@X))) 
      #Get variance of random effects by extracting variance components
      VarRand=colSums(do.call(rbind,lapply(VarCorr(i),function(j) j[1])))
      #Get residual variance
      VarResid=attr(VarCorr(i),"sc")^2
      #Calculate marginal R-squared (fixed effects/total variance)
      Rm=VarF/(VarF+VarRand+VarResid)
      #Calculate conditional R-squared (fixed effects+random effects/total variance)
      Rc=(VarF+VarRand)/(VarF+VarRand+VarResid)
      #Bind R^2s into a matrix and return with AIC values
      Rsquared.mat=data.frame(Class=class(i),Marginal=Rm,Conditional=Rc,
                              AIC=AIC(update(i,REML=F))) } 
    #For models fit using NEWER VERSION of lme4 WITH lmerTest
    else if(class(i)=="lmerMod" | class(i)=="merModLmerTest") {
      #Get variance of fixed effects by multiplying coefficients by design matrix
      VarF=var(as.vector(fixef(i) %*% t(i@pp$X))) 
      #Get variance of random effects by extracting variance components
      VarRand=colSums(do.call(rbind,lapply(VarCorr(i),function(j) j[1])))
      #Get residual variance
      VarResid=attr(VarCorr(i),"sc")^2
      #Calculate marginal R-squared (fixed effects/total variance)
      Rm=VarF/(VarF+VarRand+VarResid)
      #Calculate conditional R-squared (fixed effects+random effects/total variance)
      Rc=(VarF+VarRand)/(VarF+VarRand+VarResid)
      #Bind R^2s into a matrix and return with AIC values
      Rsquared.mat=data.frame(Class=class(i),Marginal=Rm,Conditional=Rc,
                              AIC=AIC(update(i,REML=F))) } 
    #For model fit using nlme  
    else if(class(i)=="lme") {
      #Get design matrix of fixed effects from model
      Fmat=model.matrix(eval(i$call$fixed)[-2],i$data)
      #Get variance of fixed effects by multiplying coefficients by design matrix
      VarF=var(as.vector(fixef(i) %*% t(Fmat)))
      #Get variance of random effects by extracting variance components
      VarRand=sum(suppressWarnings(as.numeric(VarCorr(i)[rownames(VarCorr(i))!=
                                                           "Residual",1])),na.rm=T)
      #Get residual variance
      VarResid=as.numeric(VarCorr(i)[rownames(VarCorr(i))=="Residual",1])
      #Calculate marginal R-squared (fixed effects/total variance)
      Rm=VarF/(VarF+VarRand+VarResid)
      #Calculate conditional R-squared (fixed effects+random effects/total variance)
      Rc=(VarF+VarRand)/(VarF+VarRand+VarResid)
      #Bind R^2s into a matrix and return with AIC values
      Rsquared.mat=data.frame(Class=class(i),Marginal=Rm,Conditional=Rc,
                              AIC=AIC(update(i,method="ML")))
    } else { print("Function requires models of class lm, lme, mer, or merMod") 
    } } ) ) }
#  rsquared.lme(list( ENTER MODEL NAMES HERE ))
#--------------------------------------------------------------------------------------------


#--------------------------------------------------------------------------------------------
##  Collinearity diagnostics

vif.mer <- function (fit) {
  ## adapted from rms::vif
  
  v <- vcov(fit)
  nam <- names(fixef(fit))
  
  ## exclude intercepts
  ns <- sum(1 * (nam == "Intercept" | nam == "(Intercept)"))
  if (ns > 0) {
    v <- v[-(1:ns), -(1:ns), drop = FALSE]
    nam <- nam[-(1:ns)]
  }
  
  d <- diag(v)^0.5
  v <- diag(solve(v/(d %o% d)))
  names(v) <- nam
  v
}

kappa.mer <- function (fit,
                       scale = TRUE, center = FALSE,
                       add.intercept = TRUE,
                       exact = FALSE) {
  X <- fit@pp$X
  nam <- names(fixef(fit))
  
  ## exclude intercepts
  nrp <- sum(1 * (nam == "(Intercept)"))
  if (nrp > 0) {
    X <- X[, -(1:nrp), drop = FALSE]
    nam <- nam[-(1:nrp)]
  }
  
  if (add.intercept) {
    X <- cbind(rep(1), scale(X, scale = scale, center = center))
    kappa(X, exact = exact)
  } else {
    kappa(scale(X, scale = scale, center = scale), exact = exact)
  }
}
#--------------------------------------------------------------------------------------------


#--------------------------------------------------------------------------------------------
####  EXAMINE/REFINE DATA  ########
names(real.data)

# Redefine numerical variables that need to be factors
my.data$year <- factor(my.data$year)
my.data$pair.id <- factor(my.data$pair.id)
my.data$female.id <- factor(my.data$female.id)
my.data$male.id <- factor(my.data$male.id)

# Centre variables and make quadratic date
real.data$lay.date.C <- scale(real.data$lay.date, center = TRUE, scale = FALSE)
real.data$incub.dur.C <- scale(real.data$incub.dur.1, center = TRUE, scale = FALSE)
real.data$male.SH.C <- scale(real.data$male.SH, center = TRUE, scale = FALSE)
real.data$pair.QGt.C <- scale(real.data$pair.QGt, center = TRUE, scale = FALSE)
real.data$lay.date.C.SQ <- real.data$lay.date.C^2

names(real.data)

# Check SH-QGt correlation 
FULL.SH.QGt.cor.data <- real.data[c("pair.id", "male.SH", "pair.QGt")]
FULL.SH.QGt.cor.data <- unique(FULL.SH.QGt.cor.data)
(FULL.SH.QGt.cor <- cor(FULL.SH.QGt.cor.data$male.SH, FULL.SH.QGt.cor.data$pair.QGt, use="complete.obs"))
# -0.297
#--------------------------------------------------------------------------------------------


#--------------------------------------------------------------------------------------------
# DO THE lme4 ANALYSES ON THE FULL DATASET
# Null model
FULL.mod.null <- lmer(TO.SEA ~ lay.date.C + lay.date.C.SQ + incub.dur.C + (1|pair.id), 
	data=real.data, REML = FALSE)

(FULL.mod.null.AICc <- AICc(FULL.mod.null))
(FULL.mod.null.vif <- vif.mer(FULL.mod.null))
(FULL.mod.null.kappa <- kappa.mer(FULL.mod.null))


# Male SH alone
FULL.mod.SH <- lmer(TO.SEA ~ lay.date.C + lay.date.C.SQ + incub.dur.C + male.SH.C + (1|pair.id), 
	data=real.data, REML = FALSE)

(FULL.mod.SH.AICc <- AICc(FULL.mod.SH))
(FULL.mod.SH.vif <- vif.mer(FULL.mod.SH))
(FULL.mod.SH.kappa <- kappa.mer(FULL.mod.SH))


# Parental similarity/relatedness alone
FULL.mod.QGt <- lmer(TO.SEA ~ lay.date.C + lay.date.C.SQ + incub.dur.C + pair.QGt.C + (1|pair.id), 
	data=real.data, REML = FALSE)

(FULL.mod.QGt.AICc <- AICc(FULL.mod.QGt))
(FULL.mod.QGt.vif <- vif.mer(FULL.mod.QGt))
(FULL.mod.QGt.kappa <- kappa.mer(FULL.mod.QGt))


# Both, no interaction
FULL.mod.BOTH <- lmer(TO.SEA ~ lay.date.C + lay.date.C.SQ + incub.dur.C
	+ male.SH.C + pair.QGt.C + (1|pair.id), data=real.data, REML = FALSE)

(FULL.mod.BOTH.AICc <- AICc(FULL.mod.BOTH))
(FULL.mod.BOTH.vif <- vif.mer(FULL.mod.BOTH))
(FULL.mod.BOTH.kappa <- kappa.mer(FULL.mod.BOTH))


# Both, with interaction
FULL.mod.INT <- lmer(TO.SEA ~ lay.date.C + lay.date.C.SQ + incub.dur.C
	+ male.SH.C*pair.QGt.C + (1|pair.id), data=real.data, REML = FALSE)

(FULL.mod.INT.AICc <- AICc(FULL.mod.INT))
(FULL.mod.INT.vif <- vif.mer(FULL.mod.INT))
(FULL.mod.INT.kappa <- kappa.mer(FULL.mod.INT))

FULL.mod.INT.summary <- summary(FULL.mod.INT)
FULL.mod.INT.coefs <- FULL.mod.INT.summary$coefficients


# Gather R2
(FULL.Rsq <- rsquared.lme(c(FULL.mod.null, FULL.mod.SH, FULL.mod.QGt, FULL.mod.BOTH, FULL.mod.INT)))


###   COLLECT THE METRICS FOR LATER COMPARISON WITH JACK-KNIFED DATA
### WHAT DO I NEED TO COLLECT FROM EACH?
# diagnostics - vif, kappa, cor(SH,QGt, use="complete.obs")
# summary metrics - dAICc, dRSq
# model parameters - slopes, SE, t


OUT.NAMES <- c("d.AICc.INT", "d.RSq.INT", "INT.slope", "INT.SE", "INT.t", 
	"kappa.INT", "VIF.max.INT", "SH.QGt.cor",
	"QGt.AICc", "BOTH.AICc", "INT.AICc",
	"QGt.RSq", "BOTH.RSq", "INT.RSq")

FULL.OUT.DATA <- c(FULL.mod.INT.AICc - FULL.mod.null.AICc,		# delta AICc of interaction model against 'null'
	FULL.Rsq$Marginal[5] - FULL.Rsq$Marginal[1],			# delta marginal R-sq of interaction
	FULL.mod.INT.coefs["male.SH.C:pair.QGt.C","Estimate"],	# coefficient of interaction term
	FULL.mod.INT.coefs["male.SH.C:pair.QGt.C","Std. Error"],	# SE for interaction term
	FULL.mod.INT.coefs["male.SH.C:pair.QGt.C","t value"],		# t-value for interaction term
	FULL.mod.INT.kappa, max(FULL.mod.INT.vif), FULL.SH.QGt.cor,	# QC diagnostics
	FULL.mod.QGt.AICc, FULL.mod.BOTH.AICc, FULL.mod.INT.AICc,	# AICc values for the three varying models
	FULL.Rsq$Marginal[3], FULL.Rsq$Marginal[4], FULL.Rsq$Marginal[5])		# RSq

names(FULL.OUT.DATA) <- OUT.NAMES
#--------------------------------------------------------------------------------------------


#--------------------------------------------------------------------------------------------
###  FUNCTION to repeat this procedure on a data subset and return the same set of outputs
#  Pass it a new dataframe that has had one family removed

MAIN <- function(NEW.DATA){
  # Check the SH-QGt correlation
  NEW.SH.QGt.cor.data <- NEW.DATA[c("pair.id", "male.SH", "pair.QGt")]
  NEW.SH.QGt.cor.data <- unique(NEW.SH.QGt.cor.data)
  NEW.SH.QGt.cor <- cor(NEW.SH.QGt.cor.data$male.SH, NEW.SH.QGt.cor.data$pair.QGt, use="complete.obs")
  
  # New models - as for full dataset
  NEW.mod.null <- lmer(TO.SEA ~ lay.date.C + lay.date.C.SQ + incub.dur.C
  	+ (1|pair.id), data=NEW.DATA, REML = FALSE)
  
  NEW.mod.null.AICc <- AICc(NEW.mod.null)
  NEW.mod.null.vif <- vif.mer(NEW.mod.null)
  NEW.mod.null.kappa <- kappa.mer(NEW.mod.null)
  
  
  NEW.mod.SH <- lmer(TO.SEA ~ lay.date.C + lay.date.C.SQ + incub.dur.C
  	+ male.SH.C + (1|pair.id), data=NEW.DATA, REML = FALSE)
  
  NEW.mod.SH.AICc <- AICc(NEW.mod.SH)
  NEW.mod.SH.vif <- vif.mer(NEW.mod.SH)
  NEW.mod.SH.kappa <- kappa.mer(NEW.mod.SH)
  
  
  NEW.mod.QGt <- lmer(TO.SEA ~ lay.date.C + lay.date.C.SQ + incub.dur.C
  	+ pair.QGt.C + (1|pair.id), data=NEW.DATA, REML = FALSE)
  
  NEW.mod.QGt.AICc <- AICc(NEW.mod.QGt)
  NEW.mod.QGt.vif <- vif.mer(NEW.mod.QGt)
  NEW.mod.QGt.kappa <- kappa.mer(NEW.mod.QGt)
  
  
  NEW.mod.BOTH <- lmer(TO.SEA ~ lay.date.C + lay.date.C.SQ + incub.dur.C
  	+ male.SH.C + pair.QGt.C + (1|pair.id), data=NEW.DATA, REML = FALSE)

  NEW.mod.BOTH.AICc <- AICc(NEW.mod.BOTH)
  NEW.mod.BOTH.vif <- vif.mer(NEW.mod.BOTH)
  NEW.mod.BOTH.kappa <- kappa.mer(NEW.mod.BOTH)
  
  
  NEW.mod.INT <- lmer(TO.SEA ~ lay.date.C + lay.date.C.SQ + incub.dur.C
  	+ male.SH.C*pair.QGt.C + (1|pair.id), data=NEW.DATA, REML = FALSE)

  NEW.mod.INT.AICc <- AICc(NEW.mod.INT)
  NEW.mod.INT.vif <- vif.mer(NEW.mod.INT)
  NEW.mod.INT.kappa <- kappa.mer(NEW.mod.INT)
  
  NEW.mod.INT.summary <- summary(NEW.mod.INT)
  NEW.mod.INT.coefs <- NEW.mod.INT.summary$coefficients
  
  
  NEW.Rsq <- rsquared.lme(c(NEW.mod.null, NEW.mod.SH, NEW.mod.QGt, NEW.mod.BOTH, NEW.mod.INT))
  
  # Gather summary stats of interest
  OUT.LINE <- c(NEW.mod.INT.AICc - NEW.mod.null.AICc,	# delta AICc of interaction model against 'null'
  	NEW.Rsq$Marginal[5] - NEW.Rsq$Marginal[1],		# delta marginal R-sq of interaction
  	NEW.mod.INT.coefs["male.SH.C:pair.QGt.C","Estimate"],	# coefficient of interaction term
  	NEW.mod.INT.coefs["male.SH.C:pair.QGt.C","Std. Error"],	# SE for interaction term
  	NEW.mod.INT.coefs["male.SH.C:pair.QGt.C","t value"],	# t-value for interaction term
  	NEW.mod.INT.kappa, max(NEW.mod.INT.vif), NEW.SH.QGt.cor,	# QC diagnostics
	NEW.mod.QGt.AICc, NEW.mod.BOTH.AICc, NEW.mod.INT.AICc,	# AICc values for the three varying models
	NEW.Rsq$Marginal[3], NEW.Rsq$Marginal[4], NEW.Rsq$Marginal[5])	# RSq
  
  return(OUT.LINE)
}
###   END OF MAIN FUNCTION
#--------------------------------------------------------------------------------------------


#--------------------------------------------------------------------------------------------
## Loop through all families, removing that family
## Keep the family, female, and male IDs, and the number of nests

# Get list of families
family.list <- as.numeric(names(table(as.numeric(real.data$pair.id))))

# Do the first family manually
FAM <- family.list[1]						# Get family ID
FAM.sub <- real.data[real.data$pair.id == FAM,]		# Get that family's subset
DATA.sub <- real.data[real.data$pair.id != FAM,]	# Get subset WITHOUT that family
OUTDATA <- MAIN(DATA.sub)					# Do the main function
OUTDATA <- c(OUTDATA, FAM, FAM.sub$female.id[1], FAM.sub$male.id[1], nrow(FAM.sub))

# Do the second row manually
FAM <- family.list[2]						# Get family ID
FAM.sub <- real.data[real.data$pair.id == FAM,]		# Get that family's subset
DATA.sub <- real.data[real.data$pair.id != FAM,]	# Get subset WITHOUT that family
OUTROW <- MAIN(DATA.sub)					# Do the main function
OUTROW <- c(OUTROW, FAM, FAM.sub$female.id[1], FAM.sub$male.id[1], nrow(FAM.sub))
OUTDATA <- rbind(OUTDATA, OUTROW)

# Loop for the rest
for(i in 3:length(family.list)){
  FAM <- family.list[i]							# Get family ID
  FAM.sub <- real.data[real.data$pair.id == FAM,]		# Get that family's subset
  DATA.sub <- real.data[real.data$pair.id != FAM,]		# Get subset WITHOUT that family
  OUTROW <- MAIN(DATA.sub)						# Do the main function
  OUTROW <- c(OUTROW, FAM, FAM.sub$female.id[1], FAM.sub$male.id[1], nrow(FAM.sub))
  OUTDATA <- rbind(OUTDATA, OUTROW)
}
# End of loop

# Dataframe and re-name cols
OUTDATA <- data.frame(OUTDATA)

OUT.NAMES <- c("d.AICc.INT", "d.RSq.INT", "INT.slope", "INT.SE", "INT.t", 
	"kappa.INT", "VIF.max.INT", "SH.QGt.cor",
	"QGt.AICc", "BOTH.AICc", "INT.AICc",
	"QGt.RSq", "BOTH.RSq", "INT.RSq", 
	"pair.id", "female.id", "male.id", "n.nests")

names(OUTDATA) <- OUT.NAMES

# Save it
write.csv(OUTDATA, "08_MAIN_jackKnifeFamilies_OUTPUTS.csv", row.names=FALSE)
#--------------------------------------------------------------------------------------------