#############################################################################################
#############################################################################################
## Re-run the main analyses, now that four families have had mal.SH and pair.SIM updated with P85 genos
##  - how well does the result hold up?
## 

# Revised 2017-08-01 for Dryad
#  - tidied, streamlined, and better annotated

#--------------------------------------------------------------------------------------------
# Clear R
rm(list = ls())

# Load necessary packages
library(lme4)
library(MuMIn)
#--------------------------------------------------------------------------------------------


#--------------------------------------------------------------------------------------------
####  BRING IN DATA  ########

# Set WD
setwd("FILEPATH")

# Read datafile
real.data <- read.csv("09_HFC_coreData_focalFamilies_useP85genos.csv")
names(real.data)
#--------------------------------------------------------------------------------------------


#--------------------------------------------------------------------------------------------
## Code for Nakagawa Rsq for LMM
## http://jslefche.wordpress.com/2013/03/13/r2-for-linear-mixed-effects-models/
## Updated by us, as original was written for lme4 in R v2

rsquared.lme=function(modlist) {
  #Iterate over each model in the list
  do.call(rbind,lapply(modlist,function(i) {
    #For models fit using lm
    if(class(i)=="lm") {
      Rsquared.mat=data.frame(Class=class(i),Marginal=summary(i)$r.squared,
                              Conditional=NA,AIC=AIC(i)) } 
    #For models fit using lme4
    else if(class(i)=="mer" | class(i)=="merMod" | class(i)=="merLmerTest") {
      #Get variance of fixed effects by multiplying coefficients by design matrix
      VarF=var(as.vector(fixef(i) %*% t(i@X))) 
      #Get variance of random effects by extracting variance components
      VarRand=colSums(do.call(rbind,lapply(VarCorr(i),function(j) j[1])))
      #Get residual variance
      VarResid=attr(VarCorr(i),"sc")^2
      #Calculate marginal R-squared (fixed effects/total variance)
      Rm=VarF/(VarF+VarRand+VarResid)
      #Calculate conditional R-squared (fixed effects+random effects/total variance)
      Rc=(VarF+VarRand)/(VarF+VarRand+VarResid)
      #Bind R^2s into a matrix and return with AIC values
      Rsquared.mat=data.frame(Class=class(i),Marginal=Rm,Conditional=Rc,
                              AIC=AIC(update(i,REML=F))) } 
    #For models fit using NEWER VERSION of lme4 WITH lmerTest
    else if(class(i)=="lmerMod" | class(i)=="merModLmerTest") {
      #Get variance of fixed effects by multiplying coefficients by design matrix
      VarF=var(as.vector(fixef(i) %*% t(i@pp$X))) 
      #Get variance of random effects by extracting variance components
      VarRand=colSums(do.call(rbind,lapply(VarCorr(i),function(j) j[1])))
      #Get residual variance
      VarResid=attr(VarCorr(i),"sc")^2
      #Calculate marginal R-squared (fixed effects/total variance)
      Rm=VarF/(VarF+VarRand+VarResid)
      #Calculate conditional R-squared (fixed effects+random effects/total variance)
      Rc=(VarF+VarRand)/(VarF+VarRand+VarResid)
      #Bind R^2s into a matrix and return with AIC values
      Rsquared.mat=data.frame(Class=class(i),Marginal=Rm,Conditional=Rc,
                              AIC=AIC(update(i,REML=F))) } 
    #For model fit using nlme  
    else if(class(i)=="lme") {
      #Get design matrix of fixed effects from model
      Fmat=model.matrix(eval(i$call$fixed)[-2],i$data)
      #Get variance of fixed effects by multiplying coefficients by design matrix
      VarF=var(as.vector(fixef(i) %*% t(Fmat)))
      #Get variance of random effects by extracting variance components
      VarRand=sum(suppressWarnings(as.numeric(VarCorr(i)[rownames(VarCorr(i))!=
                                                           "Residual",1])),na.rm=T)
      #Get residual variance
      VarResid=as.numeric(VarCorr(i)[rownames(VarCorr(i))=="Residual",1])
      #Calculate marginal R-squared (fixed effects/total variance)
      Rm=VarF/(VarF+VarRand+VarResid)
      #Calculate conditional R-squared (fixed effects+random effects/total variance)
      Rc=(VarF+VarRand)/(VarF+VarRand+VarResid)
      #Bind R^2s into a matrix and return with AIC values
      Rsquared.mat=data.frame(Class=class(i),Marginal=Rm,Conditional=Rc,
                              AIC=AIC(update(i,method="ML")))
    } else { print("Function requires models of class lm, lme, mer, or merMod") 
    } } ) ) }
#  rsquared.lme(list( ENTER MODEL NAMES HERE ))
#--------------------------------------------------------------------------------------------


#--------------------------------------------------------------------------------------------
##  Collinearity diagnostics

vif.mer <- function (fit) {
  ## adapted from rms::vif
  
  v <- vcov(fit)
  nam <- names(fixef(fit))
  
  ## exclude intercepts
  ns <- sum(1 * (nam == "Intercept" | nam == "(Intercept)"))
  if (ns > 0) {
    v <- v[-(1:ns), -(1:ns), drop = FALSE]
    nam <- nam[-(1:ns)]
  }
  
  d <- diag(v)^0.5
  v <- diag(solve(v/(d %o% d)))
  names(v) <- nam
  v
}

kappa.mer <- function (fit,
                       scale = TRUE, center = FALSE,
                       add.intercept = TRUE,
                       exact = FALSE) {
  X <- fit@pp$X
  nam <- names(fixef(fit))
  
  ## exclude intercepts
  nrp <- sum(1 * (nam == "(Intercept)"))
  if (nrp > 0) {
    X <- X[, -(1:nrp), drop = FALSE]
    nam <- nam[-(1:nrp)]
  }
  
  if (add.intercept) {
    X <- cbind(rep(1), scale(X, scale = scale, center = center))
    kappa(X, exact = exact)
  } else {
    kappa(scale(X, scale = scale, center = scale), exact = exact)
  }
}
#--------------------------------------------------------------------------------------------


#--------------------------------------------------------------------------------------------
####  EXAMINE/REFINE DATA  ########
# Reduce to focal columns
colList <- c("TO.SEA", "year", "pair.id", "female.id", "male.id",	"female.SH", "male.SH", 
	"pair.QGt", "sim.avg", "lay.date", "incub.dur.1", "male.SH.P85", "pair.QGt.P85")

real.data <- real.data[,colList]

# Redefine numerical variables that need to be factors
my.data$year <- factor(my.data$year)
my.data$pair.id <- factor(my.data$pair.id)
my.data$female.id <- factor(my.data$female.id)
my.data$male.id <- factor(my.data$male.id)

# Centre variables and make quadratic date
real.data$lay.date.C <- scale(real.data$lay.date, center = TRUE, scale = FALSE)
real.data$incub.dur.C <- scale(real.data$incub.dur.1, center = TRUE, scale = FALSE)
real.data$male.SH.C <- scale(real.data$male.SH, center = TRUE, scale = FALSE)
real.data$pair.QGt.C <- scale(real.data$pair.QGt, center = TRUE, scale = FALSE)
real.data$lay.date.C.SQ <- real.data$lay.date.C^2

names(real.data)

# Check SH-QGt correlation 
P90.SH.QGt.cor.data <- real.data[c("pair.id", "male.SH", "pair.QGt")]
P90.SH.QGt.cor.data <- unique(P90.SH.QGt.cor.data)
(P90.SH.QGt.cor <- cor(P90.SH.QGt.cor.data$male.SH, P90.SH.QGt.cor.data$pair.QGt, use="complete.obs"))
# -0.297
#--------------------------------------------------------------------------------------------


#--------------------------------------------------------------------------------------------
# DO THE lme4 ANALYSIS ON THE P90 DATASET
# Null model
P90.mod.null <- lmer(TO.SEA ~ lay.date.C + lay.date.C.SQ + incub.dur.C + (1|pair.id), 
	data=real.data, REML = FALSE)

(P90.mod.null.AICc <- AICc(P90.mod.null))
(P90.mod.null.vif <- vif.mer(P90.mod.null))
(P90.mod.null.kappa <- kappa.mer(P90.mod.null))

# Male SH alone
P90.mod.SH <- lmer(TO.SEA ~ lay.date.C + lay.date.C.SQ + incub.dur.C + male.SH.C + (1|pair.id), 
	data=real.data, REML = FALSE)

(P90.mod.SH.AICc <- AICc(P90.mod.SH))
(P90.mod.SH.vif <- vif.mer(P90.mod.SH))
(P90.mod.SH.kappa <- kappa.mer(P90.mod.SH))


# Parental relatedness/similarity alone
P90.mod.QGt <- lmer(TO.SEA ~ lay.date.C + lay.date.C.SQ + incub.dur.C + pair.QGt.C + (1|pair.id), 
	data=real.data, REML = FALSE)

(P90.mod.QGt.AICc <- AICc(P90.mod.QGt))
(P90.mod.QGt.vif <- vif.mer(P90.mod.QGt))
(P90.mod.QGt.kappa <- kappa.mer(P90.mod.QGt))


# Both, without interaction
P90.mod.BOTH <- lmer(TO.SEA ~ lay.date.C + lay.date.C.SQ + incub.dur.C
	+ male.SH.C + pair.QGt.C + (1|pair.id), data=real.data, REML = FALSE)

(P90.mod.BOTH.AICc <- AICc(P90.mod.BOTH))
(P90.mod.BOTH.vif <- vif.mer(P90.mod.BOTH))
(P90.mod.BOTH.kappa <- kappa.mer(P90.mod.BOTH))


# With interaction
P90.mod.INT <- lmer(TO.SEA ~ lay.date.C + lay.date.C.SQ + incub.dur.C
	+ male.SH.C*pair.QGt.C + (1|pair.id), data=real.data, REML = FALSE)

(P90.mod.INT.AICc <- AICc(P90.mod.INT))
(P90.mod.INT.vif <- vif.mer(P90.mod.INT))
(P90.mod.INT.kappa <- kappa.mer(P90.mod.INT))

P90.mod.INT.summary <- summary(P90.mod.INT)
P90.mod.INT.coefs <- P90.mod.INT.summary$coefficients


# Collect R2
(P90.Rsq <- rsquared.lme(c(P90.mod.null, P90.mod.SH, P90.mod.QGt, P90.mod.BOTH, P90.mod.INT)))


###   COLLECT THE METRICS FOR LATER COMPARISON WITH P85 data
### WHAT DO I NEED TO COLLECT?
# diagnostics - vif, kappa, cor(SH,QGt, use="complete.obs")
# summary metrics - dAICc, dRSq
# model parameters - slopes, SE, t

OUT.NAMES <- c("d.AICc.INT", "d.RSq.INT", "INT.slope", "INT.SE", "INT.t", 
	"kappa.INT", "VIF.max.INT", "SH.QGt.cor",
	"QGt.AICc", "BOTH.AICc", "INT.AICc",
	"QGt.RSq", "BOTH.RSq", "INT.RSq")

P90.OUT.DATA <- c(P90.mod.INT.AICc - P90.mod.null.AICc,		# delta AICc of interaction model against 'null'
	P90.Rsq$Marginal[5] - P90.Rsq$Marginal[1],			# delta marginal R-sq of interaction
	P90.mod.INT.coefs["male.SH.C:pair.QGt.C","Estimate"],		# coefficient of interaction term
	P90.mod.INT.coefs["male.SH.C:pair.QGt.C","Std. Error"],	# SE for interaction term
	P90.mod.INT.coefs["male.SH.C:pair.QGt.C","t value"],		# t-value for interaction term
	P90.mod.INT.kappa, max(P90.mod.INT.vif), P90.SH.QGt.cor,	# QC diagnostics
	P90.mod.QGt.AICc, P90.mod.BOTH.AICc, P90.mod.INT.AICc,	# AICc values for the three varying models
	P90.Rsq$Marginal[3], P90.Rsq$Marginal[4], P90.Rsq$Marginal[5])		# RSq

names(P90.OUT.DATA) <- OUT.NAMES
#--------------------------------------------------------------------------------------------


#--------------------------------------------------------------------------------------------
# NOW WITH P85 data

# mean-centre variables
real.data$male.SH.P85.C <- scale(real.data$male.SH.P85, center = TRUE, scale = FALSE)
real.data$pair.QGt.P85.C <- scale(real.data$pair.QGt.P85, center = TRUE, scale = FALSE)


# Check the SH-QGt correlation 
P85.SH.QGt.cor.data <- real.data[c("pair.id", "male.SH.P85", "pair.QGt.P85")]
P85.SH.QGt.cor.data <- unique(P85.SH.QGt.cor.data)
(P85.SH.QGt.cor <- cor(P85.SH.QGt.cor.data$male.SH.P85, P85.SH.QGt.cor.data$pair.QGt.P85, use="complete.obs"))


# DO THE lme4 ANALYSES
# Null model
P85.mod.null <- lmer(TO.SEA ~ lay.date.C + lay.date.C.SQ + incub.dur.C + (1|pair.id), 
	data=real.data, REML = FALSE)

(P85.mod.null.AICc <- AICc(P85.mod.null))
(P85.mod.null.vif <- vif.mer(P85.mod.null))
(P85.mod.null.kappa <- kappa.mer(P85.mod.null))


# Male SH only
P85.mod.SH <- lmer(TO.SEA ~ lay.date.C + lay.date.C.SQ + incub.dur.C + male.SH.P85.C + (1|pair.id), 
	data=real.data, REML = FALSE)

(P85.mod.SH.AICc <- AICc(P85.mod.SH))
(P85.mod.SH.vif <- vif.mer(P85.mod.SH))
(P85.mod.SH.kappa <- kappa.mer(P85.mod.SH))


# Parental relatedness/similarity only
P85.mod.QGt <- lmer(TO.SEA ~ lay.date.C + lay.date.C.SQ + incub.dur.C + pair.QGt.P85.C + (1|pair.id), 
	data=real.data, REML = FALSE)

(P85.mod.QGt.AICc <- AICc(P85.mod.QGt))
(P85.mod.QGt.vif <- vif.mer(P85.mod.QGt))
(P85.mod.QGt.kappa <- kappa.mer(P85.mod.QGt))


# Both, no interaction
P85.mod.BOTH <- lmer(TO.SEA ~ lay.date.C + lay.date.C.SQ + incub.dur.C
	+ male.SH.P85.C + pair.QGt.P85.C + (1|pair.id), data=real.data, REML = FALSE)

(P85.mod.BOTH.AICc <- AICc(P85.mod.BOTH))
(P85.mod.BOTH.vif <- vif.mer(P85.mod.BOTH))
(P85.mod.BOTH.kappa <- kappa.mer(P85.mod.BOTH))


# With interaction
P85.mod.INT <- lmer(TO.SEA ~ lay.date.C + lay.date.C.SQ + incub.dur.C
	+ male.SH.P85.C*pair.QGt.P85.C + (1|pair.id), data=real.data, REML = FALSE)

(P85.mod.INT.AICc <- AICc(P85.mod.INT))
(P85.mod.INT.vif <- vif.mer(P85.mod.INT))
(P85.mod.INT.kappa <- kappa.mer(P85.mod.INT))

P85.mod.INT.summary <- summary(P85.mod.INT)
P85.mod.INT.coefs <- P85.mod.INT.summary$coefficients


# Get R2
(P85.Rsq <- rsquared.lme(c(P85.mod.null, P85.mod.SH, P85.mod.QGt, P85.mod.BOTH, P85.mod.INT)))


###   COLLECT THE SAME METRICS AS USED FOR P90
OUT.NAMES <- c("d.AICc.INT", "d.RSq.INT", "INT.slope", "INT.SE", "INT.t", 
	"kappa.INT", "VIF.max.INT", "SH.QGt.cor",
	"QGt.AICc", "BOTH.AICc", "INT.AICc",
	"QGt.RSq", "BOTH.RSq", "INT.RSq")

P85.OUT.DATA <- c(P85.mod.INT.AICc - P85.mod.null.AICc,			# delta AICc of interaction model against 'null'
	P85.Rsq$Marginal[5] - P85.Rsq$Marginal[1],				# delta marginal R-sq of interaction
	P85.mod.INT.coefs["male.SH.P85.C:pair.QGt.P85.C","Estimate"],	# coefficient of interaction term
	P85.mod.INT.coefs["male.SH.P85.C:pair.QGt.P85.C","Std. Error"],	# SE for interaction term
	P85.mod.INT.coefs["male.SH.P85.C:pair.QGt.P85.C","t value"],	# t-value for interaction term
	P85.mod.INT.kappa, max(P85.mod.INT.vif), P85.SH.QGt.cor,		# QC diagnostics
	P85.mod.QGt.AICc, P85.mod.BOTH.AICc, P85.mod.INT.AICc,		# AICc values for the three varying models
	P85.Rsq$Marginal[3], P85.Rsq$Marginal[4], P85.Rsq$Marginal[5])		# RSq

names(P85.OUT.DATA) <- OUT.NAMES
#--------------------------------------------------------------------------------------------


#--------------------------------------------------------------------------------------------
# COMPARE THE TWO SETS
cbind(P90.OUT.DATA, P85.OUT.DATA)
cor.test(P90.OUT.DATA, P85.OUT.DATA, method="spearman")
cor.test(P90.OUT.DATA, P85.OUT.DATA, method="pearson")
plot(log(sqrt(P90.OUT.DATA+10)), log(sqrt(P85.OUT.DATA+10)))
#--------------------------------------------------------------------------------------------