# Perform the main interaction analysis, then repeat, shuffling the females
# Shuffling the females means that relatedness is re-sampled but male SH held constant
# Note that 'M' mean 'mother' and 'F' means 'father'

# Revised 2017-08-01 for Dryad
#  - tidied, streamlined, and better annotated

#--------------------------------------------------------------------------------------------
# Clear R
rm(list = ls())

# Load necessary packages
library(lme4)
library(MuMIn)
#--------------------------------------------------------------------------------------------


#--------------------------------------------------------------------------------------------
####  BRING IN DATA  ########

# Set WD
setwd("FILEPATH")

# Bring in data - main sheet, and relatedness matrix
observed.data <- read.csv("00_HFC_coreData_focalFamilies.csv")
rel.data <- read.csv("10_male-female_QGt_dyads.csv", row.names = "ID")
#--------------------------------------------------------------------------------------------


#--------------------------------------------------------------------------------------------
## Code for Nakagawa Rsq for LMM
## http://jslefche.wordpress.com/2013/03/13/r2-for-linear-mixed-effects-models/
## Updated by us, as original was written for lme4 in R v2

rsquared.lme=function(modlist) {
  #Iterate over each model in the list
  do.call(rbind,lapply(modlist,function(i) {
    #For models fit using lm
    if(class(i)=="lm") {
      Rsquared.mat=data.frame(Class=class(i),Marginal=summary(i)$r.squared,
                              Conditional=NA,AIC=AIC(i)) } 
    #For models fit using lme4
    else if(class(i)=="mer" | class(i)=="merMod" | class(i)=="merLmerTest") {
      #Get variance of fixed effects by multiplying coefficients by design matrix
      VarF=var(as.vector(fixef(i) %*% t(i@X))) 
      #Get variance of random effects by extracting variance components
      VarRand=colSums(do.call(rbind,lapply(VarCorr(i),function(j) j[1])))
      #Get residual variance
      VarResid=attr(VarCorr(i),"sc")^2
      #Calculate marginal R-squared (fixed effects/total variance)
      Rm=VarF/(VarF+VarRand+VarResid)
      #Calculate conditional R-squared (fixed effects+random effects/total variance)
      Rc=(VarF+VarRand)/(VarF+VarRand+VarResid)
      #Bind R^2s into a matrix and return with AIC values
      Rsquared.mat=data.frame(Class=class(i),Marginal=Rm,Conditional=Rc,
                              AIC=AIC(update(i,REML=F))) } 
    #For models fit using NEWER VERSION of lme4 WITH lmerTest
    else if(class(i)=="lmerMod" | class(i)=="merModLmerTest") {
      #Get variance of fixed effects by multiplying coefficients by design matrix
      VarF=var(as.vector(fixef(i) %*% t(i@pp$X))) 
      #Get variance of random effects by extracting variance components
      VarRand=colSums(do.call(rbind,lapply(VarCorr(i),function(j) j[1])))
      #Get residual variance
      VarResid=attr(VarCorr(i),"sc")^2
      #Calculate marginal R-squared (fixed effects/total variance)
      Rm=VarF/(VarF+VarRand+VarResid)
      #Calculate conditional R-squared (fixed effects+random effects/total variance)
      Rc=(VarF+VarRand)/(VarF+VarRand+VarResid)
      #Bind R^2s into a matrix and return with AIC values
      Rsquared.mat=data.frame(Class=class(i),Marginal=Rm,Conditional=Rc,
                              AIC=AIC(update(i,REML=F))) } 
    #For model fit using nlme  
    else if(class(i)=="lme") {
      #Get design matrix of fixed effects from model
      Fmat=model.matrix(eval(i$call$fixed)[-2],i$data)
      #Get variance of fixed effects by multiplying coefficients by design matrix
      VarF=var(as.vector(fixef(i) %*% t(Fmat)))
      #Get variance of random effects by extracting variance components
      VarRand=sum(suppressWarnings(as.numeric(VarCorr(i)[rownames(VarCorr(i))!=
                                                           "Residual",1])),na.rm=T)
      #Get residual variance
      VarResid=as.numeric(VarCorr(i)[rownames(VarCorr(i))=="Residual",1])
      #Calculate marginal R-squared (fixed effects/total variance)
      Rm=VarF/(VarF+VarRand+VarResid)
      #Calculate conditional R-squared (fixed effects+random effects/total variance)
      Rc=(VarF+VarRand)/(VarF+VarRand+VarResid)
      #Bind R^2s into a matrix and return with AIC values
      Rsquared.mat=data.frame(Class=class(i),Marginal=Rm,Conditional=Rc,
                              AIC=AIC(update(i,method="ML")))
    } else { print("Function requires models of class lm, lme, mer, or merMod") 
    } } ) ) }
#  rsquared.lme(list( ENTER MODEL NAMES HERE ))
#--------------------------------------------------------------------------------------------


#--------------------------------------------------------------------------------------------
##  Collinearity diagnostics

vif.mer <- function (fit) {
  ## adapted from rms::vif
  
  v <- vcov(fit)
  nam <- names(fixef(fit))
  
  ## exclude intercepts
  ns <- sum(1 * (nam == "Intercept" | nam == "(Intercept)"))
  if (ns > 0) {
    v <- v[-(1:ns), -(1:ns), drop = FALSE]
    nam <- nam[-(1:ns)]
  }
  
  d <- diag(v)^0.5
  v <- diag(solve(v/(d %o% d)))
  names(v) <- nam
  v
}

kappa.mer <- function (fit,
                       scale = TRUE, center = FALSE,
                       add.intercept = TRUE,
                       exact = FALSE) {
  X <- fit@pp$X
  nam <- names(fixef(fit))
  
  ## exclude intercepts
  nrp <- sum(1 * (nam == "(Intercept)"))
  if (nrp > 0) {
    X <- X[, -(1:nrp), drop = FALSE]
    nam <- nam[-(1:nrp)]
  }
  
  if (add.intercept) {
    X <- cbind(rep(1), scale(X, scale = scale, center = center))
    kappa(X, exact = exact)
  } else {
    kappa(scale(X, scale = scale, center = scale), exact = exact)
  }
}
#--------------------------------------------------------------------------------------------


#--------------------------------------------------------------------------------------------
####  EXAMINE/REFINE DATA  ########
# Turn relatedness to matrix
rel.data <- as.matrix(rel.data)

# Check
str(observed.data)
str(rel.data)

rel.data[1,1]
rel.data["M_0061","F_001"]

# Mean-centre variables
observed.data$lay.date.C <- scale(observed.data$lay.date, center = TRUE, scale = FALSE)
observed.data$incub.dur.C <- scale(observed.data$incub.dur.1, center = TRUE, scale = FALSE)
observed.data$male.SH.C <- scale(observed.data$male.SH, center = TRUE, scale = FALSE)
observed.data$pair.QGt.C <- scale(observed.data$pair.QGt, center = TRUE, scale = FALSE)

# Make quadratic date
observed.data$lay.date.C.SQ <- observed.data$lay.date.C^2


# SH-QGt correlation 
OBSERVED.SH.QGt.cor.data <- observed.data[c("pair.id", "male.SH", "pair.QGt")]
OBSERVED.SH.QGt.cor.data <- unique(OBSERVED.SH.QGt.cor.data)
(OBSERVED.SH.QGt.cor <- cor(OBSERVED.SH.QGt.cor.data$male.SH, OBSERVED.SH.QGt.cor.data$pair.QGt))
#--------------------------------------------------------------------------------------------


#--------------------------------------------------------------------------------------------
# DO THE lme4 ANALYSIS ON THE OBSERVED DATA
# Null model
OBSERVED.mod.null <- lmer(TO.SEA ~ lay.date.C + lay.date.C.SQ + incub.dur.C
	+ (1|pair.id), data=observed.data, REML = FALSE)

(OBSERVED.mod.null.AICc <- AICc(OBSERVED.mod.null))
(OBSERVED.mod.null.vif <- vif.mer(OBSERVED.mod.null))
(OBSERVED.mod.null.kappa <- kappa.mer(OBSERVED.mod.null))


# Male SH only
OBSERVED.mod.SH <- lmer(TO.SEA ~ lay.date.C + lay.date.C.SQ + incub.dur.C
	+ male.SH.C + (1|pair.id), data=observed.data, REML = FALSE)

(OBSERVED.mod.SH.AICc <- AICc(OBSERVED.mod.SH))
(OBSERVED.mod.SH.vif <- vif.mer(OBSERVED.mod.SH))
(OBSERVED.mod.SH.kappa <- kappa.mer(OBSERVED.mod.SH))


# Parental relatedness/similarity only
OBSERVED.mod.QGt <- lmer(TO.SEA ~ lay.date.C + lay.date.C.SQ + incub.dur.C
	+ pair.QGt.C + (1|pair.id), data=observed.data, REML = FALSE)

(OBSERVED.mod.QGt.AICc <- AICc(OBSERVED.mod.QGt))
(OBSERVED.mod.QGt.vif <- vif.mer(OBSERVED.mod.QGt))
(OBSERVED.mod.QGt.kappa <- kappa.mer(OBSERVED.mod.QGt))


# Both, no interaction
OBSERVED.mod.BOTH <- lmer(TO.SEA ~ lay.date.C + lay.date.C.SQ + incub.dur.C
	+ male.SH.C + pair.QGt.C + (1|pair.id), data=observed.data, REML = FALSE)

(OBSERVED.mod.BOTH.AICc <- AICc(OBSERVED.mod.BOTH))
(OBSERVED.mod.BOTH.vif <- vif.mer(OBSERVED.mod.BOTH))
(OBSERVED.mod.BOTH.kappa <- kappa.mer(OBSERVED.mod.BOTH))


# With interaction
OBSERVED.mod.INT <- lmer(TO.SEA ~ lay.date.C + lay.date.C.SQ + incub.dur.C
	+ male.SH.C*pair.QGt.C + (1|pair.id), data=observed.data, REML = FALSE)

(OBSERVED.mod.INT.AICc <- AICc(OBSERVED.mod.INT))
(OBSERVED.mod.INT.vif <- vif.mer(OBSERVED.mod.INT))
(OBSERVED.mod.INT.kappa <- kappa.mer(OBSERVED.mod.INT))

OBSERVED.mod.INT.summary <- summary(OBSERVED.mod.INT)
OBSERVED.mod.INT.coefs <- OBSERVED.mod.INT.summary$coefficients


# Get Rsq
(OBSERVED.Rsq <- rsquared.lme(c(OBSERVED.mod.null, OBSERVED.mod.SH, OBSERVED.mod.QGt, OBSERVED.mod.BOTH, OBSERVED.mod.INT)))


###   COLLECT THE METRICS FOR LATER COMPARISON WITH SHUFFLED DATA
### WHAT DO I NEED TO COLLECT FROM EACH SHUFFLE?
# diagnostics - vif, kappa, cor(SH,QGt)
# summary metrics - dAICc, dRSq
# model parameters - slopes, SE, t


OUT.NAMES <- c("d.AICc.INT", "d.RSq.INT", "INT.slope", "INT.SE", "INT.t", 
	"kappa.INT", "VIF.max.INT", "SH.QGt.cor",
	"QGt.AICc", "BOTH.AICc", "INT.AICc",
	"QGt.RSq", "BOTH.RSq", "INT.RSq")

OBSERVED.OUT.DATA <- c(OBSERVED.mod.INT.AICc - OBSERVED.mod.null.AICc,		# delta AICc of interaction model against 'null'
	OBSERVED.Rsq$Marginal[5] - OBSERVED.Rsq$Marginal[1],				# delta marginal R-sq of interaction
	OBSERVED.mod.INT.coefs["male.SH.C:pair.QGt.C","Estimate"],			# coefficient of interaction term
	OBSERVED.mod.INT.coefs["male.SH.C:pair.QGt.C","Std. Error"],		# SE for interaction term
	OBSERVED.mod.INT.coefs["male.SH.C:pair.QGt.C","t value"],			# t-value for interaction term
	OBSERVED.mod.INT.kappa, max(OBSERVED.mod.INT.vif), OBSERVED.SH.QGt.cor,		# QC diagnostics
	OBSERVED.mod.QGt.AICc, OBSERVED.mod.BOTH.AICc, OBSERVED.mod.INT.AICc,		# AICc values for the three varying models
	OBSERVED.Rsq$Marginal[3], OBSERVED.Rsq$Marginal[4], OBSERVED.Rsq$Marginal[5])		# RSq

names(OBSERVED.OUT.DATA) <- OUT.NAMES
#--------------------------------------------------------------------------------------------


#--------------------------------------------------------------------------------------------
# FUNCTION TO LOOK UP PAIRWISE RELATEDNESS OF A GIVEN PAIR
# Will be used within the context of SHUFFLE.REL() function

lookup.rel <- function(x, QGt.mat){
  x <- as.numeric(x)
  
  # Get ID numbers
  male <- x[3]
  female <- x[4]
  
  # Make strings for lookups
  male <- ifelse(male < 10, paste0("F_00", male), 
	ifelse(male < 100, paste0("F_0", male), paste0("F_", male) ))
  female <- ifelse(female < 10, paste0("M_000", female), 
	ifelse(female < 100, paste0("M_00", female), 
		ifelse(female < 1000, paste0("M_0", female), paste0("M_", female) ) ))
  
  #print(c(female,male))
  
  # Outdata
  QGt.shuffle <- QGt.mat[female, male]
  return(QGt.shuffle)
}
#--------------------------------------------------------------------------------------------


#--------------------------------------------------------------------------------------------
# Function to shuffle the relatedness values and return a new dataframe
# Will be used to make a dataframe to pass to MAIN()

SHUFFLE.REL <- function(REAL, QGt.mat){
  # get ID columns for pairs, fems and males, and reduce to uniques
  pair.list <- REAL[c("pair.id", "female.id", "male.id")]
  pair.list <- unique(pair.list)
  
  # shuffle the females and look up their QGt to their 'new' males
  pair.list$female.shuffle <- sample(pair.list$female.id)
  pair.list$QGt.shuffle <- apply(pair.list, 1, function(x) lookup.rel(x, QGt.mat))
  
  # Put the shuffled QGt back into the real (SHUFFLED) data (after copying real data)
  SHUFFLED.DATA <- REAL
  for(i in 1:nrow(SHUFFLED.DATA)){
    QGt.row <- subset(pair.list, pair.id == SHUFFLED.DATA$pair.id[i])
    SHUFFLED.DATA$pair.QGt[i] <- QGt.row$QGt.shuffle
  }
  
  # mean-centre the new QGt
  SHUFFLED.DATA$pair.QGt.C <- scale(SHUFFLED.DATA$pair.QGt, center = TRUE, scale = FALSE)
  
  return(SHUFFLED.DATA)
}
#--------------------------------------------------------------------------------------------


#--------------------------------------------------------------------------------------------
###   MAIN FUNCTION START
#  Pass it the output dataframe from SHUFFLE.REL

MAIN <- function(SHUFFLED.D){
  # Get the SH-QGt correlation 
  SHUFF.SH.QGt.cor.data <- SHUFFLED.D[c("pair.id", "male.SH", "pair.QGt")]
  SHUFF.SH.QGt.cor.data <- unique(SHUFF.SH.QGt.cor.data)
  SHUFF.SH.QGt.cor <- cor(SHUFF.SH.QGt.cor.data$male.SH, SHUFF.SH.QGt.cor.data$pair.QGt)
  
  
  # New models - as for observed dataset
  SHUFF.mod.null <- lmer(TO.SEA ~ lay.date.C + lay.date.C.SQ + incub.dur.C
  	+ (1|pair.id), data=SHUFFLED.D, REML = FALSE)
  
  SHUFF.mod.null.AICc <- AICc(SHUFF.mod.null)
  SHUFF.mod.null.vif <- vif.mer(SHUFF.mod.null)
  SHUFF.mod.null.kappa <- kappa.mer(SHUFF.mod.null)
  
  
  SHUFF.mod.SH <- lmer(TO.SEA ~ lay.date.C + lay.date.C.SQ + incub.dur.C
  	+ male.SH.C + (1|pair.id), data=SHUFFLED.D, REML = FALSE)
  
  SHUFF.mod.SH.AICc <- AICc(SHUFF.mod.SH)
  SHUFF.mod.SH.vif <- vif.mer(SHUFF.mod.SH)
  SHUFF.mod.SH.kappa <- kappa.mer(SHUFF.mod.SH)
  
  
  SHUFF.mod.QGt <- lmer(TO.SEA ~ lay.date.C + lay.date.C.SQ + incub.dur.C
  	+ pair.QGt.C + (1|pair.id), data=SHUFFLED.D, REML = FALSE)
  
  SHUFF.mod.QGt.AICc <- AICc(SHUFF.mod.QGt)
  SHUFF.mod.QGt.vif <- vif.mer(SHUFF.mod.QGt)
  SHUFF.mod.QGt.kappa <- kappa.mer(SHUFF.mod.QGt)
  
  
  SHUFF.mod.BOTH <- lmer(TO.SEA ~ lay.date.C + lay.date.C.SQ + incub.dur.C
  	+ male.SH.C + pair.QGt.C + (1|pair.id), data=SHUFFLED.D, REML = FALSE)

  SHUFF.mod.BOTH.AICc <- AICc(SHUFF.mod.BOTH)
  SHUFF.mod.BOTH.vif <- vif.mer(SHUFF.mod.BOTH)
  SHUFF.mod.BOTH.kappa <- kappa.mer(SHUFF.mod.BOTH)
  
  
  SHUFF.mod.INT <- lmer(TO.SEA ~ lay.date.C + lay.date.C.SQ + incub.dur.C
  	+ male.SH.C*pair.QGt.C + (1|pair.id), data=SHUFFLED.D, REML = FALSE)

  SHUFF.mod.INT.AICc <- AICc(SHUFF.mod.INT)
  SHUFF.mod.INT.vif <- vif.mer(SHUFF.mod.INT)
  SHUFF.mod.INT.kappa <- kappa.mer(SHUFF.mod.INT)
  
  SHUFF.mod.INT.summary <- summary(SHUFF.mod.INT)
  SHUFF.mod.INT.coefs <- SHUFF.mod.INT.summary$coefficients
  
  
  SHUFF.Rsq <- rsquared.lme(c(SHUFF.mod.null, SHUFF.mod.SH, SHUFF.mod.QGt, SHUFF.mod.BOTH, SHUFF.mod.INT))
  
  
  # Collect summary stats
  OUT.LINE <- c(SHUFF.mod.INT.AICc - SHUFF.mod.null.AICc,	# delta AICc of interaction model against 'null'
  	SHUFF.Rsq$Marginal[5] - SHUFF.Rsq$Marginal[1],		# delta marginal R-sq of interaction
  	SHUFF.mod.INT.coefs["male.SH.C:pair.QGt.C","Estimate"],	# coefficient of interaction term
  	SHUFF.mod.INT.coefs["male.SH.C:pair.QGt.C","Std. Error"],	# SE for interaction term
  	SHUFF.mod.INT.coefs["male.SH.C:pair.QGt.C","t value"],	# t-value for interaction term
  	SHUFF.mod.INT.kappa, max(SHUFF.mod.INT.vif), SHUFF.SH.QGt.cor,	# QC diagnostics
	SHUFF.mod.QGt.AICc, SHUFF.mod.BOTH.AICc, SHUFF.mod.INT.AICc,	# AICc values for the three varying models
	SHUFF.Rsq$Marginal[3], SHUFF.Rsq$Marginal[4], SHUFF.Rsq$Marginal[5])	# RSq
  
  return(OUT.LINE)
}
###   END OF MAIN FUNCTION
#--------------------------------------------------------------------------------------------


#--------------------------------------------------------------------------------------------
# Run the function 1000 times
n.reps <- 1000

# First rep, then dataframe + names
SHUFFLED.D <- SHUFFLE.REL(observed.data, rel.data)
SHUFF.OUT.DATA <- rbind(OBSERVED.OUT.DATA, MAIN(SHUFFLED.D))

SHUFF.OUT.DATA <- data.frame(SHUFF.OUT.DATA)


# Loop the rest
for(i in 1:(n.reps-1)){
  SHUFFLED.D <- SHUFFLE.REL(observed.data, rel.data)
  SHUFF.OUT.DATA <- rbind(SHUFF.OUT.DATA, MAIN(SHUFFLED.D))
}

#SAVE
#write.csv(SHUFF.OUT.DATA, "10_MAIN_shuffleFemalesAndRelatedness_OUTPUTS_1000.csv", row.names=FALSE)
#--------------------------------------------------------------------------------------------


#--------------------------------------------------------------------------------------------
# ASSESS THE OBSERVED VALUES AGAINST THE SHUFFLES

SHUFF.OUT.DATA <- SHUFF.OUT.DATA[2:nrow(SHUFF.OUT.DATA),]

# dAICc - one-tailed; how often is shuffled lower than observed
c(OBSERVED.OUT.DATA["d.AICc.INT"], (sum(SHUFF.OUT.DATA$d.AICc.INT <= OBSERVED.OUT.DATA["d.AICc.INT"])) / n.reps)

# dRsq - one-tailed; how often is shuffled greater than observed
c(OBSERVED.OUT.DATA["d.RSq.INT"], (sum(SHUFF.OUT.DATA$d.RSq.INT >= OBSERVED.OUT.DATA["d.RSq.INT"])) / n.reps)

# interaction slope - what is distance between observed and mean of shuffled, in SDs of shuffled?
(mean(SHUFF.OUT.DATA$INT.slope) - OBSERVED.OUT.DATA["INT.slope"]) / sd(SHUFF.OUT.DATA$INT.slope)

# how does kappa compare; one-tailed, how often is shuffled greater than observed
c(OBSERVED.OUT.DATA["kappa.INT"], (sum(SHUFF.OUT.DATA$kappa.INT >= OBSERVED.OUT.DATA["kappa.INT"])) / n.reps)

# how does max.VIF compare; one-tailed, how often is shuffled greater than observed
c(OBSERVED.OUT.DATA["VIF.max.INT"], (sum(SHUFF.OUT.DATA$VIF.max.INT >= OBSERVED.OUT.DATA["VIF.max.INT"])) / n.reps)

# SH-QGt correlation: observed, mean, and Probability of shuffled Cor being more negative
SH.QGt.cor.summary <- c(OBSERVED.OUT.DATA["SH.QGt.cor"], 
	mean(SHUFF.OUT.DATA$SH.QGt.cor),
	(sum(SHUFF.OUT.DATA$SH.QGt.cor <= OBSERVED.OUT.DATA["SH.QGt.cor"])) / n.reps)
names(SH.QGt.cor.summary) <- c("obs.cor", "mean.shuff.cor", "P.one.tail")
SH.QGt.cor.summary

# Does the strength of the SH-QGt correlation predict signficance (delta AICc)?
plot(SHUFF.OUT.DATA$d.AICc.INT ~ SHUFF.OUT.DATA$SH.QGt.cor)
points(x = OBSERVED.OUT.DATA["SH.QGt.cor"], y = OBSERVED.OUT.DATA["d.AICc.INT"],
	pch = 4, col = "red", lwd = 2)
#--------------------------------------------------------------------------------------------
