# Test how reconstructed parental relatedness (QGt) is affected by n.offspring, P.thresh, and n.loci

# UPDATED 2017-08-02
#  - tidy and annotate for Dryad

#---------------------------------------------------------------------------------------------------
# Clear R
rm(list=ls())

# Load packages
library(lme4)
library(MuMIn)

# Set WD
setwd("FILEPATH")
# load data
data.RECON <- read.csv("14b_exploreReconstructionParams_biasToQGt.csv")

# check data
str(data.RECON)
head(data.RECON)
tail(data.RECON)

# Prepare dataset with numerical predictors as factors
data.RECON.FACT <- data.RECON
data.RECON.FACT$P.thresh <- as.factor(data.RECON.FACT$P.thresh)
data.RECON.FACT$n.loci <- as.factor(data.RECON.FACT$n.loci)

# Make three-way factor
# Offspring number, per-locus reconstruction confidence, minimum number of male loci
three.way <- vector()
for(i in 1:nrow(data.RECON.FACT)){
  if(data.RECON.FACT[i,2] < 10){
    three.way <- c(three.way, paste(0, data.RECON.FACT[i,2], "_P", data.RECON.FACT[i,3], "_L", data.RECON.FACT[i,4], sep=""))
  }else{
    three.way <- c(three.way, paste(data.RECON.FACT[i,2], "_P", data.RECON.FACT[i,3], "_L", data.RECON.FACT[i,4], sep=""))
}}
data.RECON.FACT <- cbind(data.RECON.FACT, three.way)

data.RECON.FACT$n.offsp <- as.factor(data.RECON.FACT$n.offsp)
#---------------------------------------------------------------------------------------------------


#---------------------------------------------------------------------------------------------------
# Basic plots

# Three-way
plot(QGt.DIFF ~ three.way, data = data.RECON.FACT, las=2)

# Number of offspring
plot(QGt.DIFF ~ n.offsp, data = data.RECON.FACT, las=1,
	main = "All simulated data",
	xlab = "Number of offspring in family sample",
	ylab = "Bias in estimation of parental similarity")
lines(x=c(0,10), y=c(0,0), lty=2, col="red", lwd=2)

# Per-locus confidence
plot(QGt.DIFF ~ P.thresh, data = data.RECON.FACT, las=1,
	main = "All simulated data",
	xlab = "Per-locus reconstruction confidence threshold (%)",
	ylab = "Bias in estimation of parental similarity")
lines(x=c(0,10), y=c(0,0), lty=2, col="red", lwd=2)

# Minimum number of loci in reconstructed male
plot(QGt.DIFF ~ n.loci, data = data.RECON.FACT, las=1,
	main = "All simulated data",
	xlab = "Minimum number of loci in father genotype",
	ylab = "Bias in estimation of parental similarity")
lines(x=c(0,10), y=c(0,0), lty=2, col="red", lwd=2)

# Effect of real value on reconstructed value
plot(QGt.DIFF ~ real.QGt, data = data.RECON.FACT, las=1,
	main = "All simulated data",
	xlab = "Minimum number of loci in father genotype",
	ylab = "Bias in estimation of parental similarity")
lines(x=c(-10,10), y=c(0,0), lty=2, col="red", lwd=2)

# P95 and n.loci <29 can go
#---------------------------------------------------------------------------------------------------


#---------------------------------------------------------------------------------------------------
# Subset to n.loci=29
# Separate plots for P90 and P85

# P90
plot(QGt.DIFF ~ n.offsp, data = subset(data.RECON.FACT, P.thresh == 90 & n.loci == 29),
	main = "P-threshold = 0.90; minimum loci = 29",
	xlab = "Number of offspring in family sample",
	ylab = "Bias in estimation of parental similarity")
lines(x=c(0,10), y=c(0,0), lty=2, col="red", lwd=2)

# P85
plot(QGt.DIFF ~ n.offsp, data = subset(data.RECON.FACT, P.thresh == 85 & n.loci == 29),
	main = "P-threshold = 0.85; minimum loci = 29",
	xlab = "Number of offspring in family sample",
	ylab = "Bias in estimation of parental similarity")
lines(x=c(0,10), y=c(0,0), lty=2, col="red", lwd=2)

# Get mean bias for each number of offspring, within each P-level
data.90.29 <- subset(data.RECON.FACT, P.thresh == 90 & n.loci == 29)
data.85.29 <- subset(data.RECON.FACT, P.thresh == 85 & n.loci == 29)

tapply(data.90.29$QGt.DIFF, data.90.29$n.offsp, mean, na.rm=TRUE)
tapply(data.85.29$QGt.DIFF, data.90.29$n.offsp, mean, na.rm=TRUE)

tapply(data.90.29$QGt.DIFF, data.90.29$n.offsp, sd, na.rm=TRUE)
tapply(data.85.29$QGt.DIFF, data.90.29$n.offsp, sd, na.rm=TRUE)
#---------------------------------------------------------------------------------------------------


#---------------------------------------------------------------------------------------------------
# Do some stats

# Make full model, with family as random effect; main effects only
mod.1 <- lmer(QGt.DIFF ~ n.offsp + P.thresh + n.loci + real.QGt + (1|family.id), data=data.RECON.FACT, REML=FALSE)
summary(mod.1)

# Pretty straighforward interpretation - more offspring = good, more loci = good, stricter confidence = bad
# real.QGt is not significant, though is negative, suggesting that more similar parents have more negative bias
# Also quite a bit of family-level variance
# Will definitely be interactions!

# Test for three-way
mod.2 <- lmer(QGt.DIFF ~ n.offsp*P.thresh*n.loci + (1|family.id), data=subset(data.RECON.FACT, QGt.DIFF!="NA"), REML=FALSE, na.action=na.fail)
summary(mod.2)
# Maybe some, but probably better to pare it back
# Rank-deficiency warning

library(MuMIn)
max.dredge <- dredge(mod.2)
# Outright best is with only interaction as n.loci*P.thresh

summary(get.models(max.dredge, 1)[[1]])

#~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

# Restrict models to just n.loci = 29, and examine P85 and P90
data.29 <- subset(data.RECON.FACT, n.loci==29)

# Model for P90
mod.P90.max <- lmer(QGt.DIFF ~ n.offsp + real.QGt + (1|family.id), data=subset(data.29, P.thresh==90 & QGt.DIFF!="NA"), REML=FALSE, na.action=na.fail)
summary(mod.P90.max)
mod.P90.max.dredge <- dredge(mod.P90.max)
# Best is just number of offspring

plot(QGt.DIFF ~ n.offsp, data = subset(data.RECON.FACT, P.thresh == 90 & n.loci == 29),
	main = "P-threshold = 0.90; minimum loci = 29",
	xlab = "Number of offspring in family sample",
	ylab = "Bias in estimation of parental similarity")
lines(x=c(0,10), y=c(0,0), lty=2, col="red", lwd=2)

# Get mean and SD for all values of n.offsp
data.29.P90 <- subset(data.29, P.thresh == 90)
tapply(data.29.P90$QGt.DIFF, data.29.P90$n.offsp, function(x) mean(x,na.rm=TRUE))
tapply(data.29.P90$QGt.DIFF, data.29.P90$n.offsp, function(x) sd(x,na.rm=TRUE))
#---------------------------------------------------------------------------------------------------


#---------------------------------------------------------------------------------------------------
# Use family means for focused graphs of n=29 and P=0.85 or 0.90

# P85
subset.29 <- subset(data.RECON.FACT, n.loci==29)
subset.29.85 <- subset(subset.29, P.thresh==85)
head(subset.29.85)
n.offsp.range <- c(7, 10, 12, 15, 17, 20, 40)

# The next bit goes easier if the ranges are turned back to numbers
subset.29.85$n.offsp <- as.numeric(as.character(subset.29.85$n.offsp))
subset.29.85$family.id <- as.character(subset.29.85$family.id)

NEW.DATA.85 <- vector()
for(i in 1:length(n.offsp.range)){
  sub.1 <- subset(subset.29.85, n.offsp==n.offsp.range[i])
  sub.1.fams <- as.character(names(table(sub.1$family.id)))
  for(j in 1:length(sub.1.fams)){
    sub.2 <- subset(sub.1, family.id == sub.1.fams[j])
    new.row <- c(sub.2$n.offsp[1], sub.2$family.id[1], sub.2$real.QGt[1], mean(sub.2$QGt.DIFF))
    NEW.DATA.85 <- rbind(NEW.DATA.85, new.row)
}}

# Dataframe it, name it, turn n.off and family back to factors
NEW.DATA.85 <- data.frame(NEW.DATA.85)
names(NEW.DATA.85) <- c("n.offsp", "family.id", "real.QGt", "QGt.DIFF")
NEW.DATA.85$n.offsp <- as.factor(as.numeric(as.character(NEW.DATA.85$n.offsp)))
NEW.DATA.85$family.id <- as.factor(NEW.DATA.85$family.id)

# Because of the character strings, the numbers have been turned to strings too
NEW.DATA.85$real.QGt <- as.numeric(as.character(NEW.DATA.85$real.QGt))
NEW.DATA.85$QGt.DIFF <- as.numeric(as.character(NEW.DATA.85$QGt.DIFF))

plot(QGt.DIFF ~ n.offsp, data = NEW.DATA.85, las=1,
	ylim = c(-0.076,0.036),
	main = "P-threshold = 0.85; minimum loci = 29",
	xlab = "Number of offspring in family sample",
	ylab = "Bias in estimation of parental similarity")
lines(x=c(0,10), y=c(0,0), lty=2, col="red", lwd=2)

#~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

subset.29.90 <- subset(subset.29, P.thresh==90)
head(subset.29.90)
n.offsp.range <- c(7, 10, 12, 15, 17, 20, 40)

# The next bit goes easier if the ranges are turned back to numbers
subset.29.90$n.offsp <- as.numeric(as.character(subset.29.90$n.offsp))
subset.29.90$family.id <- as.character(subset.29.90$family.id)

NEW.DATA.90 <- vector()
for(i in 1:length(n.offsp.range)){
  sub.1 <- subset(subset.29.90, n.offsp==n.offsp.range[i])
  sub.1.fams <- as.character(names(table(sub.1$family.id)))
  for(j in 1:length(sub.1.fams)){
    sub.2 <- subset(sub.1, family.id == sub.1.fams[j])
    new.row <- c(sub.2$n.offsp[1], sub.2$family.id[1], sub.2$real.QGt[1], mean(sub.2$QGt.DIFF))
    NEW.DATA.90 <- rbind(NEW.DATA.90, new.row)
}}

# Dataframe it, name it, turn n.off and family back to factors
NEW.DATA.90 <- data.frame(NEW.DATA.90)
names(NEW.DATA.90) <- c("n.offsp", "family.id", "real.QGt", "QGt.DIFF")
NEW.DATA.90$n.offsp <- as.factor(as.numeric(as.character(NEW.DATA.90$n.offsp)))
NEW.DATA.90$family.id <- as.factor(NEW.DATA.90$family.id)

# Because of the character strings, the numbers have been turned to strings too
NEW.DATA.90$real.QGt <- as.numeric(as.character(NEW.DATA.90$real.QGt))
NEW.DATA.90$QGt.DIFF <- as.numeric(as.character(NEW.DATA.90$QGt.DIFF))

plot(QGt.DIFF ~ n.offsp, data = NEW.DATA.90, las=1,
	ylim = c(-0.076,0.036),
	main = "P-threshold = 0.90; minimum loci = 29",
	xlab = "Number of offspring in family sample",
	ylab = "Bias in estimation of parental similarity")
lines(x=c(0,10), y=c(0,0), lty=2, col="red", lwd=2)
#---------------------------------------------------------------------------------------------------
